<@pp.changeOutputFile name="test/ts/TestProperties.cpp.tmpl"/>
/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://www.eu-egee.org/partners/ for details on the copyright
 *  holders.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  Authors: Zsolt Molnar <zsolt.molnar@cern.ch>
 *  Version info: $Id: TestProperties.cpp.ftl,v 1.1 2009/12/11 11:27:04 molnarzs Exp $
 *  Release: $Name:  $
 *
 */
#include "TestProperties.h"
#include "Properties.h"
#include <glite/data/config/service/ParamReader.hxx>
#include <glite/data/config/service/ParamValue.hxx>

using namespace glite::config;

namespace glite   {
namespace data    {
namespace transfer{
namespace agent   {
namespace ts      {
namespace Property {

<#list properties as property>
void TestProperties::test${property.name}()
{
    ${property.name}::Type defaultVal = ${property.default};
    CPPUNIT_ASSERT_EQUAL(defaultVal, ${property.name}::Default());
    CPPUNIT_ASSERT_EQUAL(std::string("${property.name}"), ${property.name}::Name());
    ${property.name} v;
    CPPUNIT_ASSERT_EQUAL(defaultVal, v.value());
    // Test getting value with reader
    ${property.name}::Type fixVal = ${property.testVal};
    ParamValue pval("${property.name}", "${property.testVal}");
    ComponentConfiguration::Params params;
    ParamReader reader("TestProperties", params);
    params["${property.name}"] = &pval;
    v.read(reader);
    CPPUNIT_ASSERT_EQUAL(fixVal, v.value());
}

</#list>

void TestProperties::testStringConverter_Property_Base()
{
    CPPUNIT_ASSERT_EQUAL(size_t(2), StringConverter_Property_Base<TransferType>::_FacilityNames().size());
    CPPUNIT_ASSERT_EQUAL(size_t(3), StringConverter_Property_Base<SyslogFacility>::_FacilityNames().size());
}

void TestProperties::testStringConverter_TransferType()
{
    StringConverter<TransferType::Type> sc;
    CPPUNIT_ASSERT_EQUAL(std::string("srmcopy"), sc.to_string(TransferType::TYPE_SRMCOPY));
    CPPUNIT_ASSERT_EQUAL(TransferType::TYPE_SRMCOPY, sc.from_string("srmcopy"));

    CPPUNIT_ASSERT_EQUAL(std::string("urlcopy"), sc.to_string(TransferType::TYPE_URLCOPY));
    CPPUNIT_ASSERT_EQUAL(TransferType::TYPE_URLCOPY, sc.from_string("urlcopy"));

    CPPUNIT_ASSERT_EQUAL(size_t(2), sc.m_StringToEnum.size());
    CPPUNIT_ASSERT(sc.m_StringToEnum.find("urlcopy") != sc.m_StringToEnum.end());
    CPPUNIT_ASSERT_EQUAL(TransferType::TYPE_URLCOPY, sc.m_StringToEnum["urlcopy"]);
}

void TestProperties::testStringConverter_SysLogFacility()
{
    StringConverter<SyslogFacility::Type> sc;
    CPPUNIT_ASSERT_EQUAL(std::string("LOG_DAEMON"), sc.to_string(SyslogFacility::DAEMON));
    CPPUNIT_ASSERT_EQUAL(SyslogFacility::DAEMON, sc.from_string("LOG_DAEMON"));

    CPPUNIT_ASSERT_EQUAL(std::string("LOG_FTP"), sc.to_string(SyslogFacility::FTP));
    CPPUNIT_ASSERT_EQUAL(SyslogFacility::FTP, sc.from_string("LOG_FTP"));

    CPPUNIT_ASSERT_EQUAL(std::string("LOG_USER"), sc.to_string(SyslogFacility::USER));
    CPPUNIT_ASSERT_EQUAL(SyslogFacility::USER, sc.from_string("LOG_USER"));
}

} // end namespace Property
} // End namespace ts
} // End namespace agent
} // End namespace transfer
} // End namespace data
} // End namespace glite
