/*
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *  GLite Data Transfer Agents: CancelTransfers Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *           Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: Cancel.cpp,v 1.13 2008/11/13 10:43:55 ptedesco Exp $
 *  Release: $Name:  $
 *
 */

#error should be removed from CVS

#include "Cancel.h"
#include "ActionsConfig.h"
#include "FileFSM.h"
#include <boost/scoped_ptr.hpp>
#include <set>

using namespace glite::data::transfer::agent;
using namespace glite::data::transfer::agent::fsm;
using namespace glite::data::transfer::agent::action;
using namespace glite::data::transfer::agent::action::vo;

using glite::data::transfer::agent::dao::DAOException;
using boost::scoped_ptr; 

namespace {
const unsigned int CHUNK_SIZE = 100;
}

/*
 * Register ActionFactory Method 
 */
REGISTER_FACTORY_METHOD( Cancel );
      
/*
 * Cancel
 *
 * Constructor
 */
Cancel::Cancel():VOAction("CancelPending"){
}

/*
 * ~Cancel
 *
 * Destructor
 */
Cancel::~Cancel(){
}

/*
 * execute
 *
 * Execute the Action
 */
void Cancel::exec(const std::string& params,unsigned int& failures) /*throw (ExecuteException)*/{

    // Get File DAO
    FileDAO& fileDao = fileDAO();
        
    // Get all the non active Files which Job State is Canceling 
    // With non active state I mean Submitted, Pending, Waiting and Hold
    FileDAO::StringArray files;
    fileDao.getFilesToCancel(files,true,CHUNCK_SIZE);

    m_log_debug("Got " << files.size() << " pending files to cancel");
        
    // For Each Transfer
    std::set<std::string> ids;
    FileDAO::StringArray::iterator it;
    for(it = files.begin(); it != files.end(); ++it){
        // Process the file
        try{ 
            cancelFile((*it),ids);
        } catch(const ExecuteException& exc) {
            ++failures;
            m_log_error("Failed to cancel File [" << (*it) << "]. Reason is " << exc.what());
            m_log_warn("Process the next one");
        }
    } // End for

    // Update the Involved Job State
    this->updateJobs(ids);
}

/*
 * cancelFile
 *
 * Cancel the Pending File
 */
void Cancel::cancelFile(const std::string& file_id, std::set<std::string>& ids) /*throw (ExecuteException)*/ {

    // Get File DAO
    FileDAO& fileDao = fileDAO();
     
    // Get the File Object
    scoped_ptr<model::File> f(fileDao.get(file_id));
    try{
        m_log_debug("Canceling File [" << f->id << "] - " << f->jobId);
           
        // Check File State
        switch(f->state){
            case model::File::S_SUBMITTED:
            case model::File::S_PENDING:
            case model::File::S_WAITING:
            case model::File::S_HOLD:{
                
                m_log_debug("Trigger Event CancelRequest for File [" << f->id << "]");
        
                // Notify Cancel Request
                FileFSM f_fsm(*f);
                f_fsm.onEventCancelRequest();

                // Update File
                fileDao.update(*f);
                
                // Store Job Id
                ids.insert(f->jobId);
            }
            break;
        } // End switch
    }catch(const FSMException& exc){
        m_log_error("An error occured in canceling File [" << file_id << "]" << exc.what());
        throw ExecuteException("failed to cancel File");
    }
}
