#
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
#  This script test the smarter retry strategy
#
#  Authors: Paolo Badino <paolo.badino@cern.ch>
#  Version info: $Id: test_smarter_retry.py,v 1.10 2007/05/07 13:42:36 ptedesco Exp $
#  Release: $Name:  $
#

import time
import glite.fts
import glite.data.agents.utils
import glite.data.agents.sd
import smarter_retry
import unittest

# Define TestCase
class SmarterRetryTestCase(unittest.TestCase):
    def setUp(self):
        #config_str = \
        #    "DebugAsInfo = true\n"\
        #    "MaxFailures = 99\n"\
        #    "MaxFileExistsFailures = 3\n"\
        #    "HoldEnabled = false\n"\
        #    "OverwriteFailedFiles = true\n"\
        #    "OverwriteExistingFiles = false\n"\
        #    "DefaultRetryDelay = 599\n"\
        #    "RetryDelayForTimeoutOnGet = 1799\n"\
        #    "RetryDelayForDestFileExists = 599\n"\
        #    "SrmServiceType = srmv1\n"
        config_str = ""
        #config_str = \
        #    "DebugAsInfo = true\n"
        # Initialize the RetryStrategy
        smarter_retry.InitRetry(config_str)
    def testRetryVersion(self):
        # Check RetryVersion
        assert smarter_retry.RetryVersion() == "1.0", "Invalid RetryVersion"
    def testRetry_01(self):
        # Test Case 1: Agent Error to be retried
        job  = glite.fts.Job("Job1",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 4));
        file = glite.fts.File("1","Job1",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Agent,"An error",1,1,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 2)
        tx   = glite.fts.Transfer("req1","1",0,"Job1",glite.fts.TransferState.Failed,"urlcopy")
        tx.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 3)
        tx.reasonClass = glite.fts.ErrorCategory.Agent
        tx.reason = "An error"
        transfers = [tx]
        r = smarter_retry.Retry(job,file,transfers)
        expected = glite.fts.RetryResult.Retry
        assert r == expected, \
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_02(self):
        # Test Case 2: Agent Error not yet to be retried
        job  = glite.fts.Job("Job2",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay/2));
        file = glite.fts.File("2","Job2",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Agent,"An error",1,1,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay/4)
        tx   = glite.fts.Transfer("req1","2",0,"Job2",glite.fts.TransferState.Failed,"urlcopy")
        tx.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay/3)
        tx.reasonClass = glite.fts.ErrorCategory.Agent
        tx.reason = "An error"
        transfers = [tx]
        r = smarter_retry.Retry(job,file,transfers)
        expected = glite.fts.RetryResult.Wait
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_03(self):
        # Test Case 3: Srm Source Error timeout to be retried
        job  = glite.fts.Job("Job3",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.RetryDelayForTimeoutOnGet * 4));
        file = glite.fts.File("3","Job3",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Source," Failed on SRM get: SRM getRequestStatus timed out on get",1,1,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.RetryDelayForTimeoutOnGet * 2)
        tx   = glite.fts.Transfer("req1","3",0,"Job3",glite.fts.TransferState.Failed,"urlcopy")
        tx.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.RetryDelayForTimeoutOnGet * 3)
        tx.reasonClass = glite.fts.ErrorCategory.Source
        tx.reason = " Failed on SRM get: SRM getRequestStatus timed out on get"
        transfers = [tx]
        r = smarter_retry.Retry(job,file,transfers)
        expected = glite.fts.RetryResult.Retry
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_04(self):
        # Test Case 4: Srm Source Error timeout not yet to be retried
        job  = glite.fts.Job("Job4",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.RetryDelayForTimeoutOnGet/2));
        file = glite.fts.File("4","Job4",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Source," Failed on SRM get: SRM getRequestStatus timed out on get",1,1,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.RetryDelayForTimeoutOnGet/4)
        tx   = glite.fts.Transfer("req1","4",0,"Job4",glite.fts.TransferState.Failed,"urlcopy")
        tx.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.RetryDelayForTimeoutOnGet/3)
        tx.reasonClass = glite.fts.ErrorCategory.Source
        tx.reason = " Failed on SRM get: SRM getRequestStatus timed out on get"
        transfers = [tx]
        r = smarter_retry.Retry(job,file,transfers)
        expected = glite.fts.RetryResult.Wait
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_05(self):
        # Test Case 5: Srm Source Error timeout to be retried (multiple failures)
        job  = glite.fts.Job("Job5",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.RetryDelayForTimeoutOnGet * 10));
        file = glite.fts.File("5","Job5",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Source," Failed on SRM get: SRM getRequestStatus timed out on get",2,2,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.RetryDelayForTimeoutOnGet * 2)
        tx1  = glite.fts.Transfer("req2","5",0,"Job5",glite.fts.TransferState.Failed,"urlcopy")
        tx1.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.RetryDelayForTimeoutOnGet * 3)
        tx1.reasonClass = glite.fts.ErrorCategory.Source
        tx1.reason = " Failed on SRM get: SRM getRequestStatus timed out on get"
        tx2  = glite.fts.Transfer("req1","5",0,"Job5",glite.fts.TransferState.Failed,"urlcopy")
        tx2.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.RetryDelayForTimeoutOnGet * 10)
        tx2.reasonClass = glite.fts.ErrorCategory.Source
        tx2.reason = " Failed on SRM get: SRM getRequestStatus timed out on get"
        transfers = [tx1,tx2]
        r = smarter_retry.Retry(job,file,transfers)
        expected = glite.fts.RetryResult.Retry
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_06(self):
        # Test Case 6: Srm Source Error timeout not yet to be retried (multiple failures)
        job  = glite.fts.Job("Job6",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.RetryDelayForTimeoutOnGet/2));
        file = glite.fts.File("6","Job6",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Source," Failed on SRM get: SRM getRequestStatus timed out on get",2,2,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.RetryDelayForTimeoutOnGet/5)
        tx   = glite.fts.Transfer("req2","6",0,"Job6",glite.fts.TransferState.Failed,"urlcopy")
        tx.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.RetryDelayForTimeoutOnGet/4)
        tx.reasonClass = glite.fts.ErrorCategory.Source
        tx.reason = " Failed on SRM get: SRM getRequestStatus timed out on get"
        tx_2 = glite.fts.Transfer("req1","6",0,"Job6",glite.fts.TransferState.Failed,"urlcopy")
        tx_2.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.RetryDelayForTimeoutOnGet/3)
        tx_2.reasonClass = glite.fts.ErrorCategory.Source
        tx_2.reason = " Failed on SRM get: SRM getRequestStatus timed out on get"
        transfers = [tx,tx_2]
        r = smarter_retry.Retry(job,file,transfers)
        expected = glite.fts.RetryResult.Wait
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_07(self):
        # Test Case 7: Srm Source Error file doesn't exist
        job  = glite.fts.Job("Job7",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 4));
        file = glite.fts.File("7","Job7",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Source,"Failed on SRM get: Failed SRM get call. Error is specified file(s) does not exist",1,1,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 2)
        tx   = glite.fts.Transfer("req1","7",0,"Job7",glite.fts.TransferState.Failed,"urlcopy")
        tx.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 3)
        tx.reasonClass = glite.fts.ErrorCategory.Source
        tx.reason = "Failed on SRM get: Failed SRM get call. Error is specified file(s) does not exist"
        transfers = [tx]
        r = smarter_retry.Retry(job,file,transfers)
        expected = glite.fts.RetryResult.Fail
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_08(self):
        # Test Case 8: Srm Source Generic Error to be retried
        job  = glite.fts.Job("Job8",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 4));
        file = glite.fts.File("8","Job8",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Source,"An Error",1,1,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 2)
        tx   = glite.fts.Transfer("req1","8",0,"Job8",glite.fts.TransferState.Failed,"urlcopy")
        tx.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 3)
        tx.reasonClass = glite.fts.ErrorCategory.Source
        tx.reason = "An error"
        transfers = [tx]
        r = smarter_retry.Retry(job,file,transfers)
        expected = glite.fts.RetryResult.Retry
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_09(self):
        # Test Case 9: Srm Source Generic Error not yet to be retried
        job  = glite.fts.Job("Job9",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay/2));
        file = glite.fts.File("9","Job9",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Source,"An Error",1,1,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay/4)
        tx   = glite.fts.Transfer("req1","9",0,"Job9",glite.fts.TransferState.Failed,"urlcopy")
        tx.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay/3)
        tx.reasonClass = glite.fts.ErrorCategory.Source
        tx.reason = "An error"
        transfers = [tx]
        r = smarter_retry.Retry(job,file,transfers)
        expected = glite.fts.RetryResult.Wait
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_10(self):
        # Test Case 10: Srm Dest Error file exists to be retried
        job  = glite.fts.Job("Job10",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 4));
        file = glite.fts.File("10","Job10",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Destination,"RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]",1,1,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 2)
        tx   = glite.fts.Transfer("req1","10",0,"Job10",glite.fts.TransferState.Failed,"urlcopy")
        tx.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 3)
        tx.reasonClass = glite.fts.ErrorCategory.Destination
        tx.reason = "RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]"
        transfers = [tx]
        r = smarter_retry.Retry(job,file,transfers)
        expected = glite.fts.RetryResult.Retry
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_11(self):
        # Test Case 11: Srm Dest Error file exists not yet to be retried
        job  = glite.fts.Job("Job11",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay/2));
        file = glite.fts.File("11","Job11",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Destination,"RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]",1,1,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay/4)
        tx   = glite.fts.Transfer("req1","11",0,"Job11",glite.fts.TransferState.Failed,"urlcopy")
        tx.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay/3)
        tx.reasonClass = glite.fts.ErrorCategory.Destination
        tx.reason = "RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]"
        transfers = [tx]
        r = smarter_retry.Retry(job,file,transfers)
        expected = glite.fts.RetryResult.Wait
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_12(self):
        # Test Case 12: Srm Dest Generic to be retried
        job  = glite.fts.Job("Job12",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 4));
        file = glite.fts.File("12","Job12",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Destination,"An Error",1,1,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 2)
        tx   = glite.fts.Transfer("req1","12",0,"Job12",glite.fts.TransferState.Failed,"urlcopy")
        tx.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 3)
        tx.reasonClass = glite.fts.ErrorCategory.Destination
        tx.reason = "An error"
        transfers = [tx]
        r = smarter_retry.Retry(job,file,transfers)
        expected = glite.fts.RetryResult.Retry
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_13(self):
        # Test Case 13: Srm Dest Generic Error not yet to be retried
        job  = glite.fts.Job("Job13",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay/2));
        file = glite.fts.File("13","Job13",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Destination,"An Error",1,1,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay/4)
        tx   = glite.fts.Transfer("req1","13",0,"Job13",glite.fts.TransferState.Failed,"urlcopy")
        tx.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay/3)
        tx.reasonClass = glite.fts.ErrorCategory.Destination
        tx.reason = "An error"
        transfers = [tx]
        r = smarter_retry.Retry(job,file,transfers)
        expected = glite.fts.RetryResult.Wait
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_14(self):
        # Test Case 14: Security Error
        job  = glite.fts.Job("Job14",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 4));
        file = glite.fts.File("14","Job14",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Security,"Invalid Credentials",1,1,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 2)
        tx   = glite.fts.Transfer("req1","14",0,"Job14",glite.fts.TransferState.Failed,"urlcopy")
        tx.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 3)
        tx.reasonClass = glite.fts.ErrorCategory.Security
        tx.reason = "Invalid Credentials"
        transfers = [tx]
        r = smarter_retry.Retry(job,file,transfers)
        if(smarter_retry.g_RetryConfig.HoldEnabled == True):
            expected = glite.fts.RetryResult.Hold
        else:
            expected = glite.fts.RetryResult.Fail
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_15(self):
        # Test Case 15: Configuration Error
        job  = glite.fts.Job("Job15",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 4));
        file = glite.fts.File("15","Job15",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Configuration,"Invalid Configuration",1,1,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 2)
        tx   = glite.fts.Transfer("req1","15",0,"Job15",glite.fts.TransferState.Failed,"urlcopy")
        tx.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 3)
        tx.reasonClass = glite.fts.ErrorCategory.Configuration
        tx.reason = "Invalid Configuration"
        transfers = [tx]
        r = smarter_retry.Retry(job,file,transfers)
        if(smarter_retry.g_RetryConfig.HoldEnabled == True):
            expected = glite.fts.RetryResult.Hold
        else:
            expected = glite.fts.RetryResult.Fail
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_16(self):
        # Test Case 16: Srm Dest Error file exists with previous transfer failed to be retried
        job  = glite.fts.Job("Job16",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 5));
        file = glite.fts.File("16","Job16",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Destination,"RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]",2,2,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 2)
        tx1  = glite.fts.Transfer("req2","16",0,"Job16",glite.fts.TransferState.Failed,"urlcopy")
        tx1.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 3)
        tx1.reasonClass = glite.fts.ErrorCategory.Destination
        tx1.reason = "RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]"
        tx2  = glite.fts.Transfer("req1","16",0,"Job16",glite.fts.TransferState.Failed,"urlcopy")
        tx2.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 4)
        tx2.reasonClass = glite.fts.ErrorCategory.Transfer
        tx2.reason = "Transfer Failed"
        tx2.destSrmToken = "request_token_16_1"
        transfers = [tx1,tx2]
        r = smarter_retry.Retry(job,file,transfers)
        expected = glite.fts.RetryResult.RetryWithOverwrite
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_17(self):
        # Test Case 17: Srm Dest Error file exists with Dest failed to be retried
        job  = glite.fts.Job("Job17",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 5));
        file = glite.fts.File("17","Job17",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Destination,"RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]",2,2,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 2)
        tx1  = glite.fts.Transfer("req2","17",0,"Job17",glite.fts.TransferState.Failed,"urlcopy")
        tx1.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 3)
        tx1.reasonClass = glite.fts.ErrorCategory.Destination
        tx1.reason = "RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]"
        tx2  = glite.fts.Transfer("req1","17",0,"Job17",glite.fts.TransferState.Failed,"urlcopy")
        tx2.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 4)
        tx2.reasonClass = glite.fts.ErrorCategory.Network
        tx2.reason = "Transfer failed due to a possible network problem"
        tx2.destSrmToken = "request_token_17_1"
        transfers = [tx1,tx2]
        r = smarter_retry.Retry(job,file,transfers)
        expected = glite.fts.RetryResult.RetryWithOverwrite
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_18(self):
        # Test Case 18: Srm Dest Error file exists with Dest failed to be failed
        job  = glite.fts.Job("Job18",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * (smarter_retry.g_RetryConfig.MaxFileExistsFailures + 3)));
        file = glite.fts.File("18","Job18",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Destination,"RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]",smarter_retry.g_RetryConfig.MaxFileExistsFailures,smarter_retry.g_RetryConfig.MaxFileExistsFailures,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 2)
        transfers = list()
        for i in range(smarter_retry.g_RetryConfig.MaxFileExistsFailures):
            tx   = glite.fts.Transfer("req%d"%i,"18",0,"Job18",glite.fts.TransferState.Failed,"urlcopy")
            tx.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * (i+1) + 3)
            tx.reasonClass = glite.fts.ErrorCategory.Destination
            tx.reason = "RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]"
            transfers.append(tx)
        r = smarter_retry.Retry(job,file,transfers)
        if(smarter_retry.g_RetryConfig.HoldEnabled == True):
            expected = glite.fts.RetryResult.Hold
        else:
            expected = glite.fts.RetryResult.Fail
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_19(self):
        # Test Case 19: Transfer Error file exists to be retried
        job  = glite.fts.Job("Job19",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 4));
        file = glite.fts.File("19","Job19",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Transfer,"RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]",1,1,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 2)
        tx   = glite.fts.Transfer("req1","19",0,"Job19",glite.fts.TransferState.Failed,"urlcopy")
        tx.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 3)
        tx.reasonClass = glite.fts.ErrorCategory.Transfer
        tx.reason = "RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]"
        transfers = [tx]
        r = smarter_retry.Retry(job,file,transfers)
        expected = glite.fts.RetryResult.Retry
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_20(self):
        # Test Case 20: Transfer Error file exists not yet to be retried
        job  = glite.fts.Job("Job20",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay/2));
        file = glite.fts.File("20","Job20",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Transfer,"RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]",1,1,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay/4)
        tx   = glite.fts.Transfer("req1","20",0,"Job20",glite.fts.TransferState.Failed,"urlcopy")
        tx.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay/3)
        tx.reasonClass = glite.fts.ErrorCategory.Transfer
        tx.reason = "RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]"
        transfers = [tx]
        r = smarter_retry.Retry(job,file,transfers)
        expected = glite.fts.RetryResult.Wait
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_21(self):
        # Test Case 21: Transfer Error file exists with Dest failed to be retried
        job  = glite.fts.Job("Job21",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 5));
        file = glite.fts.File("21","Job21",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Transfer,"RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]",2,2,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 2)
        tx1  = glite.fts.Transfer("req21","21",0,"Job21",glite.fts.TransferState.Failed,"urlcopy")
        tx1.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 3)
        tx1.reasonClass = glite.fts.ErrorCategory.Transfer
        tx1.reason = "RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]"
        tx2  = glite.fts.Transfer("req1","21",0,"Job21",glite.fts.TransferState.Failed,"urlcopy")
        tx2.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 4)
        tx2.reasonClass = glite.fts.ErrorCategory.Agent
        tx2.reason = "Inconsistency found: Invalid Request state returned by transfer-url-copy"
        tx2.destSrmToken = "request_token_21_1"
        transfers = [tx1,tx2]
        r = smarter_retry.Retry(job,file,transfers)
        expected = glite.fts.RetryResult.RetryWithOverwrite
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_22(self):
        # Test Case 22: Security Error during transfer
        job  = glite.fts.Job("Job22",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 5));
        file = glite.fts.File("22","Job22",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Transfer,"RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]",2,2,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 2)
        tx1  = glite.fts.Transfer("req22","22",0,"Job22",glite.fts.TransferState.Failed,"urlcopy")
        tx1.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 3)
        tx1.reasonClass = glite.fts.ErrorCategory.Security
        tx1.reason = "TRANSFER error during TRANSFER phase: [PERMISSION] 533 533 Permission denied"
        transfers = [tx1]
        r = smarter_retry.Retry(job,file,transfers)
        expected = glite.fts.RetryResult.Retry
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testRetry_23(self):
        # Test Case 23: Aborted transfer
        job  = glite.fts.Job("Job23",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 5));
        file = glite.fts.File("23","Job23",glite.fts.FileState.Waiting,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Agent,"request aborted",1,1,0,0)
        file.finishTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 2)
        tx1  = glite.fts.Transfer("req23","23",0,"Job23",glite.fts.TransferState.Aborted,"urlcopy")
        tx1.transferTime = int(time.time()) - (smarter_retry.g_RetryConfig.DefaultRetryDelay * 3)
        tx1.reasonClass = glite.fts.ErrorCategory.Undef
        tx1.reason = ""
        transfers = [tx1]
        r = smarter_retry.Retry(job,file,transfers)
        expected = glite.fts.RetryResult.Retry
        assert r == expected,\
            ("Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
# Define Suite
def suite():
    suite = unittest.makeSuite(SmarterRetryTestCase,'test')
    return suite

# main
if __name__=="__main__":
    # The script is started from the command line: do the test
    runner = unittest.TextTestRunner()
    runner.run(suite())
