DECLARE

    v_job1 CONSTANT T_FILE.JOB_ID%TYPE := '80000000-0000-0000-0000-000000000001';
    v_job2 CONSTANT T_FILE.JOB_ID%TYPE := '80000000-0000-0000-0000-000000000002';

    -- include common procedures
    @testactions-procedures.sql
    
    -- create file procedure for smarter retry
    PROCEDURE file(
        file_id             T_FILE.FILE_ID%TYPE,
        job_id              T_FILE.JOB_ID%TYPE,
        num_failures        T_FILE.NUM_FAILURES%TYPE,
        current_failures    T_FILE.CURRENT_FAILURES%TYPE,
        reason_class        T_FILE.REASON_CLASS%TYPE,
        error_scope         T_FILE.ERROR_SCOPE%TYPE,
        error_phase         T_FILE.ERROR_PHASE%TYPE,
        reason              T_FILE.REASON%TYPE)
    IS
    BEGIN
        create_file(file_id,job_id,'Waiting',
            'srm://host.cern.ch:8443/tmp/src.txt','srm://host.in2p3.fr:8443/tmp/dst.txt',
            num_failures,current_failures,NULL,NULL,reason_class,reason,error_scope,error_phase);
    END;
    
    -- create job procedure for smarter retry
    PROCEDURE job(
        job_id              T_FILE.JOB_ID%TYPE)
    IS
    BEGIN
        create_job(job_id,'Active','DN','MyCred','SMARTERRETRY_VO_1','channel_4',NULL,NULL,
            NULL,NULL,TO_TIMESTAMP('20050101000000','YYYYMMDDHH24MISS'));
    END;    
    
    
    -- create transfer procedure for smarter retry
    PROCEDURE transfer(
        request_id      T_TRANSFER.REQUEST_ID%TYPE,
        file_id         T_TRANSFER.FILE_ID%TYPE,
        --transfer_time   T_TRANSFER.TRANSFER_TIME%TYPE,
        str_tx_time     VARCHAR2,
        reason_class    T_TRANSFER.REASON_CLASS%TYPE,
        error_scope     T_TRANSFER.ERROR_SCOPE%TYPE,
        error_phase     T_TRANSFER.ERROR_PHASE%TYPE,
        reason          T_TRANSFER.REASON%TYPE)
    IS
        transfer_time   T_TRANSFER.TRANSFER_TIME%TYPE;
    BEGIN
        IF str_tx_time is NULL THEN
            transfer_time := SYSTIMESTAMP;
        ELSE
            transfer_time := TO_TIMESTAMP(str_tx_time,'YYYYMMDDHH24MISS');
        END IF;
        create_transfer(
            request_id,file_id,0,'Failed',transfer_time,
            10.1,reason_class,reason,error_scope,error_phase); 
    END;    
BEGIN
    
    -- legacy tests (only reason_class set, deprecated values used)
    job (v_job1);
    file(80000001,v_job1,1,1,'AGENT_ERROR'         ,NULL,NULL,'An error');
    file(80000002,v_job1,1,1,'AGENT_ERROR'         ,NULL,NULL,'An error');
    file(80000003,v_job1,1,1,'SOURCE_SRM_ERROR'    ,NULL,NULL,'Failed on SRM get: SRM getRequestStatus timed out on get');
    file(80000004,v_job1,1,1,'SOURCE_SRM_ERROR'    ,NULL,NULL,'Failed on SRM get: SRM getRequestStatus timed out on get');
    file(80000005,v_job1,2,2,'SOURCE_SRM_ERROR'    ,NULL,NULL,'Failed on SRM get: SRM getRequestStatus timed out on get');
    file(80000006,v_job1,2,2,'SOURCE_SRM_ERROR'    ,NULL,NULL,'Failed on SRM get: SRM getRequestStatus timed out on get');
    file(80000007,v_job1,1,1,'SOURCE_SRM_ERROR'    ,NULL,NULL,'[SRM_INVALID_PATH] Failed on SRM get: Failed SRM get call. Error is specified file(s) does not exist');
    file(80000008,v_job1,1,1,'SOURCE_SRM_ERROR'    ,NULL,NULL,'An error');
    file(80000009,v_job1,1,1,'SOURCE_SRM_ERROR'    ,NULL,NULL,'An error');
    file(80000010,v_job1,1,1,'DEST_SRM_ERROR'      ,NULL,NULL,'[SRM_DUPLICATION_ERROR] RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]');
    file(80000011,v_job1,1,1,'DEST_SRM_ERROR'      ,NULL,NULL,'[SRM_DUPLICATION_ERROR] RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]');
    file(80000012,v_job1,1,1,'DEST_SRM_ERROR'      ,NULL,NULL,'An error');
    file(80000013,v_job1,1,1,'DEST_SRM_ERROR'      ,NULL,NULL,'An error');
    file(80000014,v_job1,1,1,'SECURITY_ERROR'      ,NULL,NULL,'Invalid Credentials');
    file(80000015,v_job1,1,1,'CONFIGURATION_ERROR' ,NULL,NULL,'Invalid Configuration');
    file(80000016,v_job1,2,2,'DEST_SRM_ERROR'      ,NULL,NULL,'[SRM_DUPLICATION_ERROR] RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write');
    file(80000017,v_job1,2,2,'DEST_PREP_SRM_ERROR' ,NULL,NULL,'[SRM_DUPLICATION_ERROR] RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]');
    file(80000018,v_job1,5,5,'DEST_SRM_ERROR'      ,NULL,NULL,'[SRM_DUPLICATION_ERROR] RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write');
    file(80000019,v_job1,1,1,'TRANSFER_ERROR'      ,NULL,NULL,'file exists, cannot write');
    file(80000020,v_job1,1,1,'TRANSFER_ERROR'      ,NULL,NULL,'file exists, cannot write');
    file(80000021,v_job1,2,2,'DEST_SRM_ERROR'      ,NULL,NULL,'[SRM_DUPLICATION_ERROR] RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write');
    file(80000022,v_job1,1,1,'SECURITY_ERROR'      ,NULL,NULL,'TRANSFER error during TRANSFER phase: [PERMISSION] 533 533 Permission denied');
    
    transfer('req_8_1_0' ,80000001,'20050101000000','AGENT_ERROR'           ,NULL,NULL,'An error');
    transfer('req_8_2_0' ,80000002,NULL            ,'AGENT_ERROR'           ,NULL,NULL,'An error');
    transfer('req_8_3_0' ,80000003,'20050101000000','SOURCE_SRM_ERROR'      ,NULL,NULL,'Failed on SRM get: SRM getRequestStatus timed out on get');
    transfer('req_8_4_0' ,80000004,NULL            ,'SOURCE_SRM_ERROR'      ,NULL,NULL,'Failed on SRM get: SRM getRequestStatus timed out on get');
    transfer('req_8_5_0' ,80000005,'20050101000000','SOURCE_SRM_ERROR'      ,NULL,NULL,'Failed on SRM get');
    transfer('req_8_5_1' ,80000005,'20060101000000','SOURCE_SRM_ERROR'      ,NULL,NULL,'Failed on SRM get: SRM getRequestStatus timed out on get');
    transfer('req_8_6_0' ,80000006,NULL            ,'SOURCE_SRM_ERROR'      ,NULL,NULL,'Failed on SRM get');
    --create_transfer('req_8_6_0' ,80000006,0,'Failed'    ,SYSTIMESTAMP - INTERVAL '1' SECOND               ,10.1,'SOURCE_SRM_ERROR','Failed on SRM get');
    transfer('req_8_6_1' ,80000006,NULL            ,'SOURCE_SRM_ERROR'      ,NULL,NULL,'Failed on SRM get: SRM getRequestStatus timed out on get');
    transfer('req_8_7_0' ,80000007,'20050101000000','SOURCE_SRM_ERROR'      ,NULL,NULL,'[SRM_INVALID_PATH] Failed on SRM get: Failed SRM get call. Error is specified file(s) does not exist');
    transfer('req_8_8_0' ,80000008,'20050101000000','SOURCE_SRM_ERROR'      ,NULL,NULL,'An error');
    transfer('req_8_9_0' ,80000009,NULL            ,'SOURCE_SRM_ERROR'      ,NULL,NULL,'An error');
    transfer('req_8_10_0',80000010,'20050101000000','DEST_SRM_ERROR'        ,NULL,NULL,'[SRM_DUPLICATION_ERROR] RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]');
    transfer('req_8_11_0',80000011,NULL            ,'DEST_SRM_ERROR'        ,NULL,NULL,'[SRM_DUPLICATION_ERROR] RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]');
    transfer('req_8_12_0',80000012,'20050101000000','DEST_SRM_ERROR'        ,NULL,NULL,'An error');
    transfer('req_8_13_0',80000013,NULL            ,'DEST_SRM_ERROR'        ,NULL,NULL,'An error');
    transfer('req_8_14_0',80000014,'20050101000000','SECURITY_ERROR'        ,NULL,NULL,'Invalid Credentials');
    transfer('req_8_15_0',80000015,'20050101000000','CONFIGURATION_ERROR'   ,NULL,NULL,'Invalid Configuration');
    transfer('req_8_16_0',80000016,'20050101000000','TRANSFER_ERROR'        ,NULL,NULL,'Transfer Failed');
    transfer('req_8_16_1',80000016,'20060101000000','DEST_SRM_ERROR'        ,NULL,NULL,'[SRM_DUPLICATION_ERROR] RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write');
    transfer('req_8_17_0',80000017,'20050101000000','NETWORK_ERROR'         ,NULL,NULL,'Transfer failed due to a possible network error');
    transfer('req_8_17_1',80000017,'20060101000000','DEST_PREP_SRM_ERROR'   ,NULL,NULL,'[SRM_DUPLICATION_ERROR] RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write ]');
    transfer('req_8_18_0',80000018,'20050101000000','TRANSFER_ERROR'        ,NULL,NULL,'An error');
    transfer('req_8_18_1',80000018,'20050102000000','TRANSFER_ERROR'        ,NULL,NULL,'An error');
    transfer('req_8_18_2',80000018,'20050103000000','TRANSFER_ERROR'        ,NULL,NULL,'An error');
    transfer('req_8_18_3',80000018,'20050104000000','TRANSFER_ERROR'        ,NULL,NULL,'An error');
    transfer('req_8_18_4',80000018,'20050105000000','DEST_SRM_ERROR'        ,NULL,NULL,'[SRM_DUPLICATION_ERROR] RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write');
    transfer('req_8_19_0',80000019,'20050101000000','TRANSFER_ERROR'        ,NULL,NULL,'file exists, cannot write');
    transfer('req_8_20_0',80000020,NULL            ,'TRANSFER_ERROR'        ,NULL,NULL,'file exists, cannot write');
    transfer('req_8_21_0',80000021,'20050101000000','AGENT_ERROR'           ,NULL,NULL,'Inconsistency found: Invalid Request state returned by transfer-url-copy');
    transfer('req_8_21_1',80000021,'20060101000000','DEST_SRM_ERROR'        ,NULL,NULL,'[SRM_DUPLICATION_ERROR] RequestFileStatus#-2147081737 failed with error:[ GetStorageInfoFailed : file exists, cannot write');
    transfer('req_8_22_0',80000022,'20050101000000','SECURITY_ERROR'        ,NULL,NULL,'TRANSFER error during TRANSFER phase: [PERMISSION] 533 533 Permission denied');
    
    -- 3.1.0 tests
    job (v_job2);
    file(80000101,v_job2,1,1,'SECURITY_ERROR','SOURCE','TRANSFER','Permission denied');
    transfer('req_8_101_0',80000101,'20050101000000','SECURITY_ERROR','SOURCE','TRANSFER','Permission denied');
    
    file(80000102,v_job2,1,1,'INVALID_PATH','SOURCE','TRANSFER_PREPARATION','File does not exist');
    transfer('req_8_102_0',80000102,'20050101000000','INVALID_PATH','SOURCE','TRANSFER_PREPARATION','File does not exist');

    file(80000103,v_job2,1,1,'FILE_EXISTS','DESTINATION','TRANSFER_PREPARATION','File exists');
    transfer('req_8_103_0',80000103,'20050101000000','FILE_EXISTS','DESTINATION','TRANSFER_PREPARATION','File exists');

    file(80000104,v_job2,3,3,'FILE_EXISTS','DESTINATION','TRANSFER_PREPARATION','File exists');
    transfer('req_8_104_2',80000104,'20050101000000','FILE_EXISTS','DESTINATION','TRANSFER_PREPARATION','File exists');
    transfer('req_8_104_1',80000104,'20040101000000','FILE_EXISTS','DESTINATION','TRANSFER_PREPARATION','File exists');
    transfer('req_8_104_0',80000104,'20030101000000','FILE_EXISTS','DESTINATION','TRANSFER_PREPARATION','File exists');
    
    file(80000105,v_job2,1,1,'REQUEST_TIMEOUT','SOURCE','TRANSFER_PREPARATION','request timed out');
    transfer('req_8_105_0',80000105,'20050101000000','REQUEST_TIMEOUT','SOURCE','TRANSFER_PREPARATION','request timed out');
    
    -- verify that if no transfer reason is present, file reason is used.
    file(80000106,v_job2,1,1,'REQUEST_TIMEOUT','SOURCE','TRANSFER_PREPARATION','request timed out');
    transfer('req_8_106_0',80000106,'20050101000000','','','','');
    file(80000107,v_job2,1,1,'REQUEST_TIMEOUT','SOURCE','TRANSFER_PREPARATION','request timed out');

    -- verify that unexpected and obsolete errors are not retried
    file(80000108,v_job2,1,1,'CONSISTENCY_ERROR','SOURCE','TRANSFER_PREPARATION','consistency error.');
    transfer('req_8_108_0',80000108,'20050101000000','CONSISTENCY','SOURCE','TRANSFER_PREPARATION','consistency error.');
    file(80000109,v_job2,1,1,'SOURCE_SRM_ERROR','SOURCE','TRANSFER_PREPARATION','consistency error.');
    transfer('req_8_109_0',80000109,NULL,'SOURCE_SRM_ERROR','SOURCE','TRANSFER_PREPARATION','consistency error.');
    
END;
/
