
/**
 * create_channel
 * Insert Channel Procedure
 */
PROCEDURE create_channel(
    n    T_CHANNEL.CHANNEL_NAME%TYPE,
    src  T_CHANNEL.SOURCE_SITE%TYPE,
    dst  T_CHANNEL.DEST_SITE%TYPE,
    st   T_CHANNEL.CHANNEL_STATE%TYPE,
    f    T_CHANNEL.NOFILES%TYPE DEFAULT 10,
    sl   T_CHANNEL.SE_LIMIT%TYPE DEFAULT NULL)
IS          
    ch_type T_CHANNEL.CHANNEL_TYPE%TYPE;
BEGIN
    IF (src = '*' OR  dst = '*' OR src LIKE '[%]' OR dst LIKE '[%]') THEN
        ch_type := 'NONDEDICATED';
    ELSE 
        ch_type := 'DEDICATED';
    END IF;
        
    INSERT INTO t_channel(channel_name,source_site,dest_site,channel_state,nofiles,se_limit,channel_type,preparing_files_ratio)
        VALUES (n,src,dst,st,f,sl,ch_type,2);
END;

/**
 * create_ch_vo_share
 * Insert Channel VO Share procedure
 */
PROCEDURE create_ch_vo_share(
                            n    T_CHANNEL_VO_SHARE.CHANNEL_NAME%TYPE,
                            v    T_CHANNEL_VO_SHARE.VO_NAME%TYPE,
                            s    T_CHANNEL_VO_SHARE.CHANNEL_SHARE%TYPE,
                            l    T_CHANNEL_VO_SHARE.CHANNEL_LIMIT%TYPE DEFAULT NULL,
                            vs   T_CHANNEL_VO_SHARE.CHANNEL_VOSTATE%TYPE DEFAULT NULL)
IS                            
BEGIN
    INSERT INTO t_channel_vo_share(channel_name,vo_name,channel_share,channel_limit,channel_vostate) 
        VALUES (n,v,s,l,vs);
END;

/**  
 * create_job
 * Insert Job Procedure
 */
PROCEDURE create_job(
    j    T_JOB.JOB_ID%TYPE,
    st   T_JOB.JOB_STATE%TYPE,
    dn   T_JOB.USER_DN%TYPE, 
    cr   T_JOB.USER_CRED%TYPE,
    vo   T_JOB.VO_NAME%TYPE, 
    ch   T_JOB.CHANNEL_NAME%TYPE,
    src  T_JOB.SOURCE%TYPE, 
    dst  T_JOB.DEST%TYPE,
    cj   T_JOB.CANCEL_JOB%TYPE DEFAULT NULL,
    ip   T_JOB.INTERNAL_JOB_PARAMS%TYPE DEFAULT NULL,
    jst  T_JOB.SUBMIT_TIME%TYPE DEFAULT NULL,
    s_se T_JOB.SOURCE_SE%TYPE DEFAULT NULL, 
    d_se T_JOB.DEST_SE%TYPE DEFAULT NULL)
IS         
    v_source_se VARCHAR2(256);
    v_dest_se   VARCHAR2(256);
BEGIN
    IF s_se IS NULL THEN
        v_source_se := src;
    ELSE 
        v_source_se := s_se;
    END IF;
    IF d_se IS NULL THEN
        v_dest_se := dst;
    ELSE 
        v_dest_se := d_se;
    END IF;
    
    IF jst IS NULL THEN
        INSERT INTO t_job(job_id,job_state,user_dn,user_cred,vo_name,channel_name,source,dest,cancel_job, internal_job_params, source_se, dest_se) 
            VALUES (j,st,dn,cr,vo,ch,src,dst,cj,ip, v_source_se, v_dest_se);
    ELSE 
        INSERT INTO t_job(job_id,job_state,user_dn,user_cred,vo_name,channel_name,source,dest,cancel_job, internal_job_params,submit_time, source_se, dest_se) 
            VALUES (j,st,dn,cr,vo,ch,src,dst,cj,ip,jst, v_source_se, v_dest_se);
    END IF;
END;

/**  
 * create_file
 * Insert File Procedure
 */
PROCEDURE create_file(
    file_id             T_FILE.FILE_ID%TYPE,
    job_id              T_FILE.JOB_ID%TYPE,
    file_state          T_FILE.FILE_STATE%TYPE,
    source_surl         T_FILE.SOURCE_SURL%TYPE, 
    dest_surl           T_FILE.DEST_SURL%TYPE,
    num_failures        T_FILE.NUM_FAILURES%TYPE DEFAULT NULL,
    current_failures    T_FILE.CURRENT_FAILURES%TYPE DEFAULT NULL,
    catalog_failures    T_FILE.CATALOG_FAILURES%TYPE DEFAULT NULL,
    logical_name        T_FILE.LOGICAL_NAME%TYPE DEFAULT NULL,
    reason_class        T_FILE.REASON_CLASS%TYPE DEFAULT NULL,
    reason              T_FILE.REASON%TYPE DEFAULT NULL,
    error_scope         T_FILE.ERROR_SCOPE%TYPE DEFAULT NULL,
    error_phase         T_FILE.ERROR_PHASE%TYPE DEFAULT NULL)
IS
BEGIN
    INSERT INTO t_file(
        file_id,job_id,file_state,source_surl,dest_surl,num_failures,
        current_failures,catalog_failures,logical_name,reason_class,reason,
        error_scope,error_phase) 
    VALUES (
        file_id,job_id,file_state,source_surl,dest_surl,num_failures,
        current_failures,catalog_failures,logical_name,reason_class,reason,
        error_scope,error_phase);
END;

/**
 * create_transfer
 * Insert Transfer Procedure
 */ 
PROCEDURE create_transfer(
    request_id      T_TRANSFER.REQUEST_ID%TYPE,
    f_id            T_TRANSFER.FILE_ID%TYPE,
    transfer_id     T_TRANSFER.TRANSFER_ID%TYPE,
    transfer_state  T_TRANSFER.TRANSFER_STATE%TYPE,
    transfer_time   T_TRANSFER.TRANSFER_TIME%TYPE, 
    duration        T_TRANSFER.DURATION%TYPE,
    reason_class    T_TRANSFER.REASON_CLASS%TYPE DEFAULT NULL,
    reason          T_TRANSFER.REASON%TYPE DEFAULT NULL,
    error_scope     T_TRANSFER.ERROR_SCOPE%TYPE DEFAULT NULL,
    error_phase     T_TRANSFER.ERROR_PHASE%TYPE DEFAULT NULL)
IS
    j_id  T_TRANSFER.JOB_ID%TYPE;                        
BEGIN
    SELECT T_FILE.JOB_ID into j_id FROM T_FILE WHERE T_FILE.FILE_ID = f_id;
    INSERT INTO t_transfer(
        request_id,file_id,transfer_id,job_id,transfer_state,transfer_time,
        duration,reason_class,reason,error_scope,error_phase) 
    VALUES (
        request_id,f_id,transfer_id,j_id,transfer_state,transfer_time,
        duration,reason_class,reason,error_scope,error_phase);
END;
