#!/bin/bash
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#-------------------------------------------------------------------------------
# Unit tests for org.glite.data.transfer-agents actions
# Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
# Version info: $Id: unit-test.sh,v 1.4 2009/07/02 15:21:17 molnarzs Exp $
# Release: $Name:  $
#-------------------------------------------------------------------------------
# The tests use the stub transfer service.

#some configuration parameters for the tests...
ts_stub_maxtransfers=20
ts_stub_maxrequestsize=1

# install service discovery stub
function test_actions_sd_stub_install(){
    # create services.xml file
    cat > "${MODULE_TEST_DIR}/etc/services.xml" << EOD
<services>
  <service name="Stub_Catalog">
    <parameters>
      <endpoint>none</endpoint>
      <type>TestPythonCatalog</type>
      <version>0.0.0</version>
    </parameters>
  </service>
  <service name="Stub_Catalog_CERN">
    <parameters>
      <endpoint>test://localhost:1234</endpoint>
      <type>TestLocalPythonCatalog</type>
      <version>0.0.0</version>
      <site>test.cern.ch</site>
    </parameters>
  </service>
  <service name="Stub_Catalog_RAL">
    <parameters>
      <endpoint>test://somewhere:1234</endpoint>
      <type>TestLocalPythonCatalog</type>
      <version>0.0.0</version>
      <site>test.ral.ac.uk</site>
    </parameters>
  </service> 
  <service name="CERN-SRM">
    <parameters>
      <endpoint>httpg://host.cern.ch:8443/srm/managerv1</endpoint>
      <type>SRM</type>
      <version>1.1.0</version>
      <site>test.cern.ch</site>
      <param name="ALLOCATE_VO_1:SEMountPoint">/castor/cern.ch/SE/</param>
      <param name="ALLOCATE_VO_BUGS:SEMountPoint">/castor/cern.ch/SE/</param>
    </parameters>
  </service>
  <service name="BAD-CERN-SRM">
    <parameters>
      <endpoint>httpg://bad.cern.ch:8443/srm/managerv1</endpoint>
      <type>SRM</type>
      <version>1.1.0</version>
      <site>test.cern.ch</site>
      <param name="ALLOCATE_VO_1:SEMountPoint">/castor/cern.ch/SE/</param>
    </parameters>
  </service>
  <service name="INFN-SRM">
    <parameters>
      <endpoint>httpg://host.infn.it:8443/srm/managerv1</endpoint>
      <type>SRM</type>
      <version>1.1.0</version>
      <site>test.infn.it</site>
      <param name="ALLOCATE_VO_1:SEMountPoint">/castor/infn.it/EGEE-SE/</param>
      <param name="ALLOCATE_VO_BUGS:SEMountPoint">/castor/infn.it/EGEE-SE/</param>
    </parameters>
  </service>
  <service name="INFN2-SRM">
    <parameters>
      <endpoint>httpg://host2.infn.it:8443/srm/managerv1</endpoint>
      <type>SRM</type>
      <version>1.1.0</version>
      <site>test.infn.it</site>
      <param name="ALLOCATE_VO_1:SEMountPoint">/castor/infn.it/EGEE-SE/</param>
      <param name="ALLOCATE_VO_BUGS:SEMountPoint">/castor/infn.it/EGEE-SE/</param>
    </parameters>
  </service>
  <service name="BAD-INFN-SRM">
    <parameters>
      <endpoint>httpg://bad.infn.it:8443/srm/managerv1</endpoint>
      <type>SRM</type>
      <version>1.1.0</version>
      <site>badsite.infn.it</site>
      <param name="ALLOCATE_VO_1:SEMountPoint">/castor/infn.it/EGEE-SE/</param>
    </parameters>
  </service>
  <service name="RAL-SRM">
    <parameters>
      <endpoint>https://host.ral.ac.uk:8443/srm/managerv1</endpoint>
      <type>SRM</type>
      <version>1.1.0</version>
      <site>test.ral.ac.uk</site>
      <param name="ALLOCATE_VO_1:SEMountPoint">/pnfs/ral.ac.uk/SE/VOLATILE/</param>
    </parameters>
  </service> 
  <service name="DESY-SRM">
    <parameters>
      <endpoint>httpg://host.desy.de:8443/srm/managerv1</endpoint>
      <type>SRM</type>
      <version>1.1.0</version>
      <site>test.desy.de</site>
      <param name="ALLOCATE_VO_1:SEMountPoint">/pnfs/desy.de/SE/VOLATILE/</param>
    </parameters>
  </service>   
  <service name="FNAL-SRM">
    <parameters>
      <endpoint>httpg://host.fnal.gov:8443/srm/managerv1</endpoint>
      <type>SRM</type>
      <version>1.1.0</version>
      <site>test.fnal.gov</site>
      <param name="ALLOCATE_VO_1:SEMountPoint">/pnfs/fnal.gov/SE/VOLATILE/</param>
    </parameters>
  </service>   
  <service name="BNL-SRM">
    <parameters>
      <endpoint>httpg://host.bnl.gov:8443/srm/managerv1</endpoint>
      <type>SRM</type>
      <version>1.1.0</version>
      <site>test.bnl.gov</site>
      <param name="ALLOCATE_VO_1:SEMountPoint">/pnfs/bnl.gov/SE/VOLATILE/</param>
    </parameters>
  </service>   
  <service name="SARA-SRM">
    <parameters>
      <endpoint>httpg://host.nikhef.nl:8443/srm/managerv1</endpoint>
      <type>SRM</type>
      <version>1.1.0</version>
      <site>test.nikhef.nl</site>
      <param name="SEMountPoint">/pnfs/nikhef.nl/SE/VOLATILE/</param>
    </parameters>
  </service>   
  <service name="SITE.CERN-SRM">
    <parameters>
      <endpoint>httpg://host1.cern.ch:8443/srm/managerv1</endpoint>
      <type>SRM</type>
      <version>1.1.0</version>
      <site>site.cern.ch</site>
      <param name="ALLOCATE_VO_2:SEMountPoint">/castor/cern.ch/SE/</param>
    </parameters>
  </service>
  <service name="SITE.INFN-SRM">
    <parameters>
      <endpoint>httpg://host1.infn.it:8443/srm/managerv1</endpoint>
      <type>SRM</type>
      <version>1.1.0</version>
      <site>site.infn.it</site>
      <param name="ALLOCATE_VO_2:SEMountPoint">/castor/infn.it/EGEE-SE/</param>
    </parameters>
  </service>
  <service name="SITE.CATANIA-SRM">
    <parameters>
      <endpoint>httpg://host1.catania.infn.it:8443/srm/managerv1</endpoint>
      <type>SRM</type>
      <version>1.1.0</version>
      <site>site.catania.it</site>
      <param name="ALLOCATE_VO_2:SEMountPoint">/castor/catania.infn.it/EGEE-SE/</param>
    </parameters>
  </service>  
  <service name="SITE.PISA-SRM">
    <parameters>
      <endpoint>httpg://host1.pisa.infn.it:8443/srm/managerv1</endpoint>
      <type>SRM</type>
      <version>1.1.0</version>
      <site>site.pisa.it</site>
      <param name="ALLOCATE_VO_2:SEMountPoint">/castor/pisa.infn.it/EGEE-SE/</param>
    </parameters>
  </service>  
  <service name="SITE.RAL-SRM">
    <parameters>
      <endpoint>https://host1.ral.ac.uk:8443/srm/managerv1</endpoint>
      <type>SRM</type>
      <version>1.1.0</version>
      <site>site.ral.ac.uk</site>
      <param name="ALLOCATE_VO_2:SEMountPoint">/pnfs/ral.ac.uk/SE/VOLATILE/</param>
    </parameters>
  </service> 
</services>
EOD
}

# Install Python Catalog stub
TEST_ACTIONS_PYTHON_PACKAGES_DIR=""
function test_actions_python_stub_install(){
    TEST_ACTIONS_PYTHON_PACKAGES_DIR=`python -c "from distutils import sysconfig; print sysconfig.get_python_lib(1,0,prefix='${GLITE_LOCATION}')"`
    info "TEST_ACTIONS_PYTHON_PACKAGES_DIR = ${TEST_ACTIONS_PYTHON_PACKAGES_DIR}"
    cp ${MODULE_DIR}/test/catalog/python/scripts/TestCatalog.py ${MODULE_TEST_DIR}/bin
}

# Install Actions UnitTest Data (populates the database)
test_actions_ora_install__DEPENDS="init_unit_test test_actions_sd_stub_install test_actions_python_stub_install"
function test_actions_ora_install(){
    local SRC_DIR="${MODULE_DIR}/test/actions/scripts"
    local DEST_DIR="${MODULE_TEST_DIR}/bin"
   
    # populate DB
    clear_db || return ${?}
    
    # copy sql scripts and bash script to run them
    cp -v ${SRC_DIR}/ora_t_site_group_insert.sql ${DEST_DIR}
    cp -v ${SRC_DIR}/testactions-*.sql ${DEST_DIR}
   
    (cd ${DEST_DIR} && RunSqlCmd \
        "testactions-t_channel_insert.sql" \
        "testactions-t_channel_vo_share_insert.sql" \
        "testactions-t_job_insert.sql" \
        "testactions-t_file_insert.sql" \
        "testactions-t_transfer_insert.sql" \
        "ora_t_site_group_insert.sql" \
        "testactions-smarterretry.sql") || return ${?}
     
    # create configuration xml file
    local TEMPLATES_DIR="${GLITE_LOCATION}/share/test/"
    local AGENTS_COMMON_CONFIG_TEMPLATES="${GLITE_LOCATION}/share/config/glite-data-agents-common/config-templates"
    create_config_xml "glite-transfer-agent-test-actions-ora" "${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-actions-oracle.config.xml" \
        "${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-cred-myproxy.config-template.xml" \
        "${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-sd.config-template.xml" \
        "${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-python.config-template.xml" \
        "${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-dao-oracle.config-template.xml" \
        "${MODULE_DIR}/test/ts/etc/transfer-agent-ts-stub.config-template.xml" \
        "${MODULE_CONFIG_TEMPLATES}/transfer-agent-catalog-python.config-template.xml" \
        "${MODULE_CONFIG_TEMPLATES}/transfer-agent-dao-oracle.config-template.xml" \
        "${MODULE_CONFIG_TEMPLATES}/transfer-agent-vo-actions.config-template.xml" \
        "${MODULE_CONFIG_TEMPLATES}/transfer-agent-channel-actions.config-template.xml"

    # Create the unit test configuration
    config_generator -f ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-actions-oracle.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-actions-ora.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-actions-ora.log-properties \
        -O agents-cred-myproxy.Server=${MYPROXY_SERVER} \
        -O agents-cred-myproxy.ProxyLifetime=300 \
        -O agents-cred-myproxy.MinValidityTime=0 \
        -O agents-dao-oracle.User=${ORA_USER} \
        -O agents-dao-oracle.Password=${ORA_PWD} \
        -O agents-dao-oracle.ConnectString=${ORA_CONNECTSTRING} \
        -O agents-python.PythonPath=${TEST_ACTIONS_PYTHON_PACKAGES_DIR}:${MODULE_TEST_DIR}/bin \
        -O transfer-agent-catalog-python.CatalogModule=TestCatalog \
        -O transfer-agent-vo-actions.EnableDelegation=false \
        -O transfer-agent-vo-actions.MaxFailures=6 \
        -O transfer-agent-vo-actions.ResubmitDelay=300 \
        -O transfer-agent-vo-actions.EnableUnknownSource=false \
        -O transfer-agent-vo-actions.EnableUnknownDest=true \
        -O transfer-agent-channel-actions.EnableDelegation=false \
        -O transfer-agent-ts-stub.MaxTransfers=${ts_stub_maxtransfers} \
        -O transfer-agent-ts-stub.MaxRequestSize=${ts_stub_maxrequestsize} \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/glite-transfer-agent-test-actions-oracle.log \
        -O log.Priority=DEBUG
}

# Actions Unit Test
test_actions_ora__DEPENDS="test_actions_ora_install"
function test_actions_ora(){
    local TEST_EXE="${MODULE_TEST_DIR}/bin/glite_data_transfer_agent_test_actions"
    local WORK_DIR="${MODULE_TEST_DIR}/bin"
    
    echo "About to execute:"
    echo "${TEST_EXE} -l ${MODULE_TEST_DIR} -c glite-transfer-agent-test-actions-ora -e test://localhost:1234 -s"
    
    cd ${WORK_DIR}
    ${TEST_EXE} -l ${MODULE_TEST_DIR} -c glite-transfer-agent-test-actions-ora -e test://localhost:1234 -s
        
    echo "Ready"
    local res=${?}
    rm -rf ${MODULE_TEST_DIR}/bin/ts-stub__*
    if [ 0 -ne ${res} ]; then
        return ${res}
    fi
}

# DEPENDS : test-actions-sd-stub-install,test-actions-python-stub-install
test_actions_python_install__DEPENDS="init_unit_test test_actions_sd_stub_install test_actions_python_stub_install"
function test_actions_python_install(){
    # Populate DB
    run_test_function test_actions_ora_install
    # Create template for the unit test
    local AGENTS_COMMON_CONFIG_TEMPLATES="${GLITE_LOCATION}/share/config/glite-data-agents-common/config-templates"
    create_config_xml "glite-transfer-agent-test-actions-python-oracle" "${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-actions-python-oracle.config.xml" \
        "${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-cred-myproxy.config-template.xml" \
        "${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-sd.config-template.xml" \
        "${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-python.config-template.xml" \
        "${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-dao-oracle.config-template.xml" \
        "${MODULE_DIR}/test/ts/etc/transfer-agent-ts-stub.config-template.xml" \
        "${MODULE_CONFIG_TEMPLATES}/transfer-agent-catalog-python.config-template.xml" \
        "${MODULE_CONFIG_TEMPLATES}/transfer-agent-dao-oracle.config-template.xml" \
        "${MODULE_CONFIG_TEMPLATES}/transfer-agent-vo-actions.config-template.xml" \
        "${MODULE_CONFIG_TEMPLATES}/transfer-agent-vo-actions-python.config-template.xml" \
        "${MODULE_CONFIG_TEMPLATES}/transfer-agent-channel-actions.config-template.xml"
    # Create UnitTest configuration
    config_generator -f ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-actions-python-oracle.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-actions-python-oracle.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-actions-python-oracle.log-properties \
        -O agents-cred-myproxy.Server=${MYPROXY_SERVER} \
        -O agents-cred-myproxy.ProxyLifetime=300 \
        -O agents-cred-myproxy.MinValidityTime=0 \
        -O agents-dao-oracle.User=${ORA_USER} \
        -O agents-dao-oracle.Password=${ORA_PWD} \
        -O agents-dao-oracle.ConnectString=${ORA_CONNECTSTRING} \
        -O agents-python.PythonPath=${TEST_ACTIONS_PYTHON_PACKAGES_DIR}:${MODULE_TEST_DIR}/bin:${PYTHON_LIB_PATH}/glite/fts/strategies \
        -O transfer-agent-catalog-python.CatalogModule=TestCatalog \
        -O transfer-agent-ts-stub.MaxTransfers=${ts_stub_maxtransfers} \
        -O transfer-agent-ts-stub.MaxRequestSize=${ts_stub_maxrequestsize} \
        -O transfer-agent-vo-actions.EnableDelegation=false \
        -O transfer-agent-vo-actions.MaxFailures=6 \
        -O transfer-agent-vo-actions.ResubmitDelay=300 \
        -O transfer-agent-vo-actions.EnableUnknownSource=false \
        -O transfer-agent-vo-actions.EnableUnknownDest=true \
        -O transfer-agent-channel-actions.EnableDelegation=false \
        -O transfer-agent-vo-actions-python.RetryModule=basic_retry \
        -O transfer-agent-vo-actions-python.RetryParams='param1=1; param2=2' \
        -O transfer-agent-vo-actions-python.CatalogRetryModule=basic_catalog_retry \
        -O transfer-agent-vo-actions-python.CatalogRetryParams='param3=3; param4=4' \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/glite-transfer-agent-test-actions-python-oracle.log \
        -O log.Priority=DEBUG
        
    config_generator -f ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-actions-python-oracle.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-actions-py-smarter-oracle.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-actions-py-smarter-oracle.log-properties \
        -O agents-cred-myproxy.Server=${MYPROXY_SERVER} \
        -O agents-cred-myproxy.ProxyLifetime=300 \
        -O agents-cred-myproxy.MinValidityTime=0 \
        -O agents-dao-oracle.User=${ORA_USER} \
        -O agents-dao-oracle.Password=${ORA_PWD} \
        -O agents-dao-oracle.ConnectString=${ORA_CONNECTSTRING} \
        -O agents-python.PythonPath=${TEST_ACTIONS_PYTHON_PACKAGES_DIR}:${MODULE_TEST_DIR}/bin:${PYTHON_LIB_PATH}/glite/fts/strategies \
        -O transfer-agent-catalog-python.CatalogModule=TestCatalog \
        -O transfer-agent-ts-stub.MaxTransfers=${ts_stub_maxtransfers} \
        -O transfer-agent-ts-stub.MaxRequestSize=${ts_stub_maxrequestsize} \
        -O transfer-agent-vo-actions.EnableDelegation=false \
        -O transfer-agent-vo-actions.MaxFailures=6 \
        -O transfer-agent-vo-actions.ResubmitDelay=300 \
        -O transfer-agent-vo-actions.EnableUnknownSource=false \
        -O transfer-agent-vo-actions.EnableUnknownDest=true \
        -O transfer-agent-channel-actions.EnableDelegation=false \
        -O transfer-agent-vo-actions-python.RetryModule=smarter_retry \
        -O transfer-agent-vo-actions-python.RetryParams="DebugAsInfo=true;MaxFailures=3" \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/glite-transfer-agent-test-actions-py-smarter-oracle.log \
        -O log.Priority=DEBUG
}

# Actions unit test
function test_actions_python(){
    run_test_function test_actions_python_install
    local TEST_EXE="${MODULE_TEST_DIR}/bin/glite_data_transfer_agent_test_actions"
    local WORK_DIR="${MODULE_TEST_DIR}/bin"
    cd ${WORK_DIR} 
    
    echo "GLITE_LOCATION=${MODULE_TEST_DIR} ${TEST_EXE} -l ${MODULE_TEST_DIR} -c glite-transfer-agent-test-actions-python-oracle -e test://localhost:1234 -P -s"
    
    ldd ${TEST_EXE}
    
    #env GLITE_LOCATION="${MODULE_TEST_DIR}" ${TEST_EXE} -l ${MODULE_TEST_DIR} -c glite-transfer-agent-test-actions-python-oracle -e test://localhost:1234 -P -s
    ${TEST_EXE} -l ${MODULE_TEST_DIR} -c glite-transfer-agent-test-actions-python-oracle -e test://localhost:1234 -P -s

    local res=${?}
    echo "RETURN: $res"
    rm -rf ${MODULE_TEST_DIR}/bin/ts_stub__*
    return ${res}
}

# Actions unit test
function test_actions_py_smarter(){
    run_test_function test_actions_python_install
    local TEST_EXE="${MODULE_TEST_DIR}/bin/glite_data_transfer_agent_test_actions"
    local WORK_DIR="${MODULE_TEST_DIR}/bin"
    (cd ${WORK_DIR} && env \
        GLITE_LOCATION="${MODULE_TEST_DIR}" ${TEST_EXE} -l ${MODULE_TEST_DIR} \
        -c glite-transfer-agent-test-actions-py-smarter-oracle \
        -e test://localhost:1234 -P -x -s)
    local res=${?}
    rm -rf ${MODULE_TEST_DIR}/bin/ts_stub__*
    return ${res}
}

# Install Test Python Strategies UnitTests Data
test_python_strategies_install__DEPENDS="init_unit_test"
function test_python_strategies_install(){
    cp ${MODULE_DIR}/test/actions/scripts/*.py ${MODULE_TEST_DIR}/bin
}

# run python test script specified in the "test_script" parameter
function test_python_strategy(){
    test_script=${1}
    TEST_ACTIONS_PYTHON_PACKAGES_DIR=`python -c "from distutils import sysconfig; print sysconfig.get_python_lib(1,0,prefix='${GLITE_LOCATION}')"`
    local WORK_DIR="${MODULE_TEST_DIR}/bin"
    (cd ${WORK_DIR} && env PYTHONPATH=${TEST_ACTIONS_PYTHON_PACKAGES_DIR}:${PYTHON_LIB_PATH}/glite/fts/strategies \
        PATH=${PATH}:${GLITE_LOCATION}/bin:${MODULE_TEST_DIR}/bin:${GLITE_LOCATION}/libexec \
        GLITE_LOCATION=${MODULE_TEST_DIR} \
        python ${MODULE_TEST_DIR}/bin/${test_script})
    return ${?}
}

# Test Python Strategies
test_python_strategies__DEPENDS="test_python_strategies_install"
function test_python_strategies(){
    test_python_strategy test_basic_retry.py
    test_python_strategy test_smarter_retry.py 
    test_python_strategy test_basic_catalog_retry.py
}    
 
# Actions unit test
test_actions__DEPENDS="test_actions_ora test_actions_python test_python_strategies test_actions_py_smarter" 
function test_actions(){
    true
}     

