DECLARE
-- Insert File Procedure
PROCEDURE test_create_file(
                            f    T_FILE.FILE_ID%TYPE,
                            j    T_FILE.JOB_ID%TYPE,
                            st   T_FILE.FILE_STATE%TYPE,
                            src  T_FILE.SOURCE_SURL%TYPE, 
                            dst  T_FILE.DEST_SURL%TYPE,
                            l    T_FILE.LOGICAL_NAME%TYPE DEFAULT NULL)
IS                            
BEGIN
    INSERT INTO t_file(file_id,job_id,file_state,source_surl,dest_surl,logical_name) 
        VALUES (f,j,st,src,dst,l);
END;

-- Insert File Procedure (3.1.0 specific properties)
PROCEDURE test_create_file_3_1_0(
                            f           T_FILE.FILE_ID%TYPE,
                            j           T_FILE.JOB_ID%TYPE,
                            st          T_FILE.FILE_STATE%TYPE,
                            r           T_FILE.REASON%TYPE,
                            r_class     T_FILE.REASON_CLASS%TYPE,
                            err_scope   T_FILE.ERROR_SCOPE%TYPE,
                            err_phase   T_FILE.ERROR_PHASE%TYPE)
IS                            
BEGIN
    INSERT INTO t_file(file_id,job_id,file_state,
        source_surl,dest_surl,
        reason,reason_class,error_scope,error_phase) 
        VALUES (f,j,st,
        'file://source.cern.ch:80/tmp/src.txt','file://dest.cern.ch:80/tmp/dst.txt',
        r,r_class,err_scope,err_phase);
END;

PROCEDURE test_create_file_finished(
                            f    T_FILE.FILE_ID%TYPE,
                            j    T_FILE.JOB_ID%TYPE,
                            st   T_FILE.FILE_STATE%TYPE,
                            src  T_FILE.SOURCE_SURL%TYPE, 
                            dst  T_FILE.DEST_SURL%TYPE,
                            l    T_FILE.LOGICAL_NAME%TYPE DEFAULT NULL)
IS                            
BEGIN
    INSERT INTO t_file(file_id,job_id,file_state,source_surl,dest_surl,logical_name,job_finished) 
        VALUES (f,j,st,src,dst,l,CURRENT_DATE);
END;

-- Main
BEGIN
	-- Set Records
    test_create_file(10000001,'00000000-0000-0000-0000-000000000001','Active'                   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000002,'00000000-0000-0000-0000-000000000001','Waiting'                  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000003,'00000000-0000-0000-0000-000000000002','Done'                     ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000004,'00000000-0000-0000-0000-000000000002','Done'                     ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000005,'00000000-0000-0000-0000-000000000003','Pending'                  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000006,'00000000-0000-0000-0000-000000000003','Waiting'                  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000007,'00000000-0000-0000-0000-000000000004','Pending'                  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000008,'00000000-0000-0000-0000-000000000005','Done'                     ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_8');
    test_create_file(10000009,'00000000-0000-0000-0000-000000000006','Waiting'                  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000010,'00000000-0000-0000-0000-000000000006','Done'                     ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_8');
    test_create_file(10000011,'00000000-0000-0000-0000-000000000007','Pending'                  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_8');
    test_create_file(10000012,'00000000-0000-0000-0000-000000000007','WaitingCatalogResolution' ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_8');
    test_create_file(10000013,'00000000-0000-0000-0000-000000000008','WaitingCatalogResolution' ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_8');
    test_create_file(10000014,'00000000-0000-0000-0000-000000000008','WaitingCatalogResolution' ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_8');
    test_create_file(10000015,'00000000-0000-0000-0000-000000000009','WaitingCatalogResolution' ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_8');
    test_create_file(10000016,'00000000-0000-0000-0000-000000000009','WaitingCatalogResolution' ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_8');
    test_create_file(10000017,'00000000-0000-0000-0000-000000000009','Pending'                  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_8');
    test_create_file(10000018,'00000000-0000-0000-0000-000000000010','Finishing'                ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_8');
    test_create_file(10000019,'00000000-0000-0000-0000-000000000010','Finished'                 ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_8');
    test_create_file(10000020,'00000000-0000-0000-0000-000000000010','WaitingCatalogRegistration','file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_8');
    test_create_file(10000021,'00000000-0000-0000-0000-000000000011','WaitingCatalogRegistration','file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_8');
    test_create_file(10000022,'00000000-0000-0000-0000-000000000011','WaitingCatalogRegistration','file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_8');
    test_create_file(10000023,'00000000-0000-0000-0000-000000000012','Failed'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_8');
    test_create_file(10000024,'00000000-0000-0000-0000-000000000012','WaitingCatalogRegistration','file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_8');
    test_create_file(10000025,'00000000-0000-0000-0000-000000000012','Finishing','file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_8');
    test_create_file(10000026,'00000000-0000-0000-0000-000000000013','Ready'    ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000027,'00000000-0000-0000-0000-000000000013','Ready'    ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000028,'00000000-0000-0000-0000-000000000013','Ready'    ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000029,'00000000-0000-0000-0000-000000000014','Active'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000030,'00000000-0000-0000-0000-000000000014','Ready'    ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000031,'00000000-0000-0000-0000-000000000015','Ready'    ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000032,'00000000-0000-0000-0000-000000000015','Ready'    ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000033,'00000000-0000-0000-0000-000000000015','Canceled' ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000034,'00000000-0000-0000-0000-000000000015','Failed'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000035,'00000000-0000-0000-0000-000000000016','Active'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000036,'00000000-0000-0000-0000-000000000016','Waiting'  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000037,'00000000-0000-0000-0000-000000000016','Ready'    ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000038,'00000000-0000-0000-0000-000000000017','Done'     ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000039,'00000000-0000-0000-0000-000000000017','Hold'     ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000040,'00000000-0000-0000-0000-000000000018','Active'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(10000101,'00000000-0000-0000-0000-000000000101','Ready'    ,'file://host1.cern.ch:80/tmp/src.txt','file://host2.cern.ch:80/tmp/dst.txt');
    test_create_file(10000102,'00000000-0000-0000-0000-000000000101','Ready'    ,'file://host1.cern.ch:80/tmp/src.txt','file://host2.cern.ch:80/tmp/dst.txt');
    test_create_file(10000103,'00000000-0000-0000-0000-000000000101','Ready'    ,'file://host1.cern.ch:80/tmp/src.txt','file://host2.cern.ch:80/tmp/dst.txt');
    test_create_file(10000104,'00000000-0000-0000-0000-000000000102','Ready'    ,'file://host1.cern.ch:80/tmp/src.txt','file://host2.cern.ch:80/tmp/dst.txt');
    test_create_file(10000105,'00000000-0000-0000-0000-000000000102','Ready'    ,'file://host1.cern.ch:80/tmp/src.txt','file://host2.cern.ch:80/tmp/dst.txt');
    test_create_file(10000106,'00000000-0000-0000-0000-000000000102','Ready'    ,'file://host1.cern.ch:80/tmp/src.txt','file://host2.cern.ch:80/tmp/dst.txt');
    test_create_file(10000107,'00000000-0000-0000-0000-000000000103','Ready'    ,'file://host1.cern.ch:80/tmp/src.txt','file://host3.cern.ch:80/tmp/dst.txt');
    test_create_file(10000108,'00000000-0000-0000-0000-000000000103','Ready'    ,'file://host1.cern.ch:80/tmp/src.txt','file://host3.cern.ch:80/tmp/dst.txt');
    test_create_file(10000109,'00000000-0000-0000-0000-000000000103','Ready'    ,'file://host1.cern.ch:80/tmp/src.txt','file://host3.cern.ch:80/tmp/dst.txt');
    test_create_file(10000110,'00000000-0000-0000-0000-000000000104','Ready'    ,'file://host1.cern.ch:80/tmp/src.txt','file://host3.cern.ch:80/tmp/dst.txt');
    test_create_file(10000111,'00000000-0000-0000-0000-000000000104','Ready'    ,'file://host1.cern.ch:80/tmp/src.txt','file://host3.cern.ch:80/tmp/dst.txt');
    test_create_file(10000112,'00000000-0000-0000-0000-000000000104','Ready'    ,'file://host1.cern.ch:80/tmp/src.txt','file://host3.cern.ch:80/tmp/dst.txt');
    test_create_file(10000113,'00000000-0000-0000-0000-000000000105','Ready'    ,'file://host2.cern.ch:80/tmp/src.txt','file://host3.cern.ch:80/tmp/dst.txt');
    test_create_file(10000114,'00000000-0000-0000-0000-000000000105','Ready'    ,'file://host2.cern.ch:80/tmp/src.txt','file://host3.cern.ch:80/tmp/dst.txt');
    test_create_file(10000115,'00000000-0000-0000-0000-000000000105','Ready'    ,'file://host2.cern.ch:80/tmp/src.txt','file://host3.cern.ch:80/tmp/dst.txt');
    test_create_file(10000116,'00000000-0000-0000-0000-000000000106','Ready'    ,'file://host2.cern.ch:80/tmp/src.txt','file://host3.cern.ch:80/tmp/dst.txt');
    test_create_file(10000117,'00000000-0000-0000-0000-000000000106','Ready'    ,'file://host2.cern.ch:80/tmp/src.txt','file://host3.cern.ch:80/tmp/dst.txt');
    test_create_file(10000118,'00000000-0000-0000-0000-000000000106','Ready'    ,'file://host2.cern.ch:80/tmp/src.txt','file://host3.cern.ch:80/tmp/dst.txt');
    test_create_file(10000119,'00000000-0000-0000-0000-000000000107','Ready'    ,'file://host2.cern.ch:80/tmp/src.txt','file://host1.cern.ch:80/tmp/dst.txt');
    test_create_file(10000120,'00000000-0000-0000-0000-000000000107','Ready'    ,'file://host2.cern.ch:80/tmp/src.txt','file://host1.cern.ch:80/tmp/dst.txt');
    test_create_file(10000121,'00000000-0000-0000-0000-000000000107','Ready'    ,'file://host2.cern.ch:80/tmp/src.txt','file://host1.cern.ch:80/tmp/dst.txt');
    test_create_file(10000122,'00000000-0000-0000-0000-000000000108','Ready'    ,'file://host2.cern.ch:80/tmp/src.txt','file://host1.cern.ch:80/tmp/dst.txt');
    test_create_file(10000123,'00000000-0000-0000-0000-000000000108','Ready'    ,'file://host2.cern.ch:80/tmp/src.txt','file://host1.cern.ch:80/tmp/dst.txt');
    test_create_file(10000124,'00000000-0000-0000-0000-000000000108','Ready'    ,'file://host2.cern.ch:80/tmp/src.txt','file://host1.cern.ch:80/tmp/dst.txt');
    test_create_file(10000125,'00000000-0000-0000-0000-000000000109','Ready'    ,'file://host3.cern.ch:80/tmp/src.txt','file://host1.cern.ch:80/tmp/dst.txt');
    test_create_file(10000126,'00000000-0000-0000-0000-000000000109','Ready'    ,'file://host3.cern.ch:80/tmp/src.txt','file://host1.cern.ch:80/tmp/dst.txt');
    test_create_file(10000127,'00000000-0000-0000-0000-000000000109','Ready'    ,'file://host3.cern.ch:80/tmp/src.txt','file://host1.cern.ch:80/tmp/dst.txt');
    test_create_file(10000128,'00000000-0000-0000-0000-000000000110','Ready'    ,'file://host3.cern.ch:80/tmp/src.txt','file://host1.cern.ch:80/tmp/dst.txt');
    test_create_file(10000129,'00000000-0000-0000-0000-000000000110','Ready'    ,'file://host3.cern.ch:80/tmp/src.txt','file://host1.cern.ch:80/tmp/dst.txt');
    test_create_file(10000130,'00000000-0000-0000-0000-000000000110','Ready'    ,'file://host3.cern.ch:80/tmp/src.txt','file://host1.cern.ch:80/tmp/dst.txt');
    test_create_file(20000001,'10000000-0000-0000-0000-000000000001','Active'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000002,'10000000-0000-0000-0000-000000000001','Done'     ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000003,'10000000-0000-0000-0000-000000000002','Ready'    ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000004,'10000000-0000-0000-0000-000000000002','Ready'    ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000005,'10000000-0000-0000-0000-000000000003','Active'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000006,'10000000-0000-0000-0000-000000000003','Pending'  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000007,'10000000-0000-0000-0000-000000000004','Active'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000008,'10000000-0000-0000-0000-000000000005','Submitted','file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000009,'10000000-0000-0000-0000-000000000006','Submitted','file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000010,'10000000-0000-0000-0000-000000000007','Active'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000011,'10000000-0000-0000-0000-000000000008','Finished' ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_11');
    test_create_file(20000012,'10000000-0000-0000-0000-000000000009','WaitingCatalogResolution' ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_11');
    test_create_file(20000013,'10000000-0000-0000-0000-000000000009','Ready'    ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_11');
    test_create_file(20000014,'10000000-0000-0000-0000-000000000010','Submitted','file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_11');
    test_create_file(20000015,'10000000-0000-0000-0000-000000000010','Ready'    ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt','/test_11');
    test_create_file(20000016,'10000000-0000-0000-0000-000000000011','Done'     ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000017,'10000000-0000-0000-0000-000000000011','Done'     ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000018,'10000000-0000-0000-0000-000000000012','Done'     ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000019,'10000000-0000-0000-0000-000000000012','Failed'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000020,'10000000-0000-0000-0000-000000000013','Finishing','file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000021,'10000000-0000-0000-0000-000000000013','Finishing','file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000022,'10000000-0000-0000-0000-000000000014','WaitingCatalogRegistration','file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000023,'10000000-0000-0000-0000-000000000014','Finished','file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000024,'10000000-0000-0000-0000-000000000015','Finishing','file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000025,'10000000-0000-0000-0000-000000000015','Finished','file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000026,'10000000-0000-0000-0000-000000000016','Finished','file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000027,'10000000-0000-0000-0000-000000000016','Finished','file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000028,'10000000-0000-0000-0000-000000000017','Finished','file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000029,'10000000-0000-0000-0000-000000000017','Failed'  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000030,'10000000-0000-0000-0000-000000000018','Pending' ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000031,'10000000-0000-0000-0000-000000000018','Failed'  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000032,'10000000-0000-0000-0000-000000000019','AwaitingPrestage','file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000033,'10000000-0000-0000-0000-000000000019','Prestaging','file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000034,'10000000-0000-0000-0000-000000000020','Ready'    ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000035,'10000000-0000-0000-0000-000000000020','Pending'  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000036,'10000000-0000-0000-0000-000000000021','Active'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000037,'10000000-0000-0000-0000-000000000021','Pending'  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000038,'10000000-0000-0000-0000-000000000022','Done'     ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000039,'10000000-0000-0000-0000-000000000022','Failed'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000040,'10000000-0000-0000-0000-000000000023','Failed'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000041,'10000000-0000-0000-0000-000000000023','Hold'     ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000042,'10000000-0000-0000-0000-000000000024','Canceled' ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000043,'10000000-0000-0000-0000-000000000024','Hold'     ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000044,'10000000-0000-0000-0000-000000000025','Pending'  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000045,'10000000-0000-0000-0000-000000000025','Hold'     ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000046,'10000000-0000-0000-0000-000000000030','Active'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(20000047,'10000000-0000-0000-0000-000000000031','Active'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(30000001,'20000000-0000-0000-0000-000000000001','Active'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(30000002,'20000000-0000-0000-0000-000000000001','Done'     ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(30000003,'20000000-0000-0000-0000-000000000002','Active'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(30000004,'20000000-0000-0000-0000-000000000003','Done'     ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(30000005,'20000000-0000-0000-0000-000000000003','Waiting'  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(30000006,'20000000-0000-0000-0000-000000000004','Pending'  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(30000007,'20000000-0000-0000-0000-000000000005','Active'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(30000008,'20000000-0000-0000-0000-000000000006','Active'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(30001000,'20000000-0000-0000-0000-000000000007','Pending'  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(30000009,'20000000-0000-0000-0000-000000000008','Active'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(40000001,'30000000-0000-0000-0000-000000000001','Active'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(40000002,'30000000-0000-0000-0000-000000000002','Active'   ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(40000003,'30000000-0000-0000-0000-000000000002','Ready'    ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(50000001,'40000000-0000-0000-0000-000000000001','Pending'  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(50000002,'40000000-0000-0000-0000-000000000001','Ready'    ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(50000003,'40000000-0000-0000-0000-000000000002','Pending'  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(50000004,'40000000-0000-0000-0000-000000000003','Pending'  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(50000005,'40000000-0000-0000-0000-000000000003','WaitingPrestage','file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(50000006,'40000000-0000-0000-0000-000000000004','Pending'  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(50000007,'40000000-0000-0000-0000-000000000005','Pending'  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(50000008,'40000000-0000-0000-0000-000000000006','Pending'  ,'file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    test_create_file(50001000,'40000000-0000-0000-0000-000000000007','Submitted','file://host.cern.ch:80/tmp/src.txt','file://host.in2p3.fr:80/tmp/dst.txt');
    -- 3.1.0 specific tests
    test_create_file_3_1_0(60000001,'60000000-0000-0000-0000-000000000002','Failed','http timeout','HTTP_TIMEOUT','SOURCE','TRANSFER_PREPARATION');
    test_create_file_3_1_0(60000002,'60000000-0000-0000-0000-000000000002','Failed','some reason','GRIDFTP_ERROR','TRANSFER','TRANSFER');
    test_create_file_3_1_0(60000003,'60000000-0000-0000-0000-000000000002','Failed','some reason','CONNECTION_ERROR','DESTINATION','TRANSFER_FINALIZATION');
    test_create_file(60000004,'60000000-0000-0000-0000-000000000003','Active','file://source.cern.ch:80/tmp/src2.txt','file://dest.cern.ch:80/tmp/dst2.txt');
    -- bug specific tests
    test_create_file(70000001,'70000000-0000-0000-0000-000000000001','Active','file://source.foo:80/tmp/foo.txt','file://dest.bar:80/tmp/bar.txt');
    
    -- GetShare tests and refactoring  
    test_create_file(90100001,'90000000-0000-0000-0000-000000000001','Ready','file://source.foo:80/tmp/foo.txt','file://dest.bar:80/tmp/bar.txt');
    test_create_file(90200001,'90000000-0000-0000-0000-000000000002','Active','file://source.foo:80/tmp/foo.txt','file://dest.bar:80/tmp/bar.txt');

    test_create_file(90300001,'90000000-0000-0000-0000-000000000003','Ready','file://source.foo:80/tmp/foo.txt','file://dest.bar:80/tmp/bar.txt');
    test_create_file(90400001,'90000000-0000-0000-0000-000000000004','Ready','file://source.foo:80/tmp/foo.txt','file://dest.bar:80/tmp/bar.txt');
    
    test_create_file(90500001,'90000000-0000-0000-0000-000000000005','Ready','file://source.foo:80/tmp/foo.txt','file://dest.bar:80/tmp/bar.txt');
    test_create_file(90600001,'90000000-0000-0000-0000-000000000006','Ready','file://source.foo:80/tmp/foo.txt','file://dest.bar:80/tmp/bar.txt');
    test_create_file(90600002,'90000000-0000-0000-0000-000000000006','Ready','file://source.foo:80/tmp/foo.txt','file://dest.bar:80/tmp/bar.txt');
    test_create_file(90600003,'90000000-0000-0000-0000-000000000006','Ready','file://source.foo:80/tmp/foo.txt','file://dest.bar:80/tmp/bar.txt');
    test_create_file(90700001,'90000000-0000-0000-0000-000000000007','Ready','file://source.foo:80/tmp/foo.txt','file://dest.bar:80/tmp/bar.txt');

    test_create_file(90800001,'90000000-0000-0000-0000-000000000008','Waiting','file://source.foo:80/tmp/foo.txt','file://dest.bar:80/tmp/bar.txt');
    test_create_file(90900001,'90000000-0000-0000-0000-000000000009','Waiting','file://source.foo:80/tmp/foo.txt','file://dest.bar:80/tmp/bar.txt');
    test_create_file(91000001,'90000000-0000-0000-0000-000000000010','Ready','file://source.foo:80/tmp/foo.txt','file://dest.bar:80/tmp/bar.txt');
    test_create_file(91100001,'90000000-0000-0000-0000-000000000011','Ready','file://source.foo:80/tmp/foo.txt','file://dest.bar:80/tmp/bar.txt');
    test_create_file(91100002,'90000000-0000-0000-0000-000000000011','Ready','file://source.foo:80/tmp/foo.txt','file://dest.bar:80/tmp/bar.txt');
    test_create_file(91100003,'90000000-0000-0000-0000-000000000011','Ready','file://source.foo:80/tmp/foo.txt','file://dest.bar:80/tmp/bar.txt');
    test_create_file(91200001,'90000000-0000-0000-0000-000000000012','Ready','file://source.foo:80/tmp/foo.txt','file://dest.bar:80/tmp/bar.txt');
    test_create_file(91200002,'90000000-0000-0000-0000-000000000012','Ready','file://source.foo:80/tmp/foo.txt','file://dest.bar:80/tmp/bar.txt');
    test_create_file(91200003,'90000000-0000-0000-0000-000000000012','Ready','file://source.foo:80/tmp/foo.txt','file://dest.bar:80/tmp/bar.txt');
            
END;
/
