#!/bin/bash
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#------------------------------------------------------------------------------
# transfer-agents.dao.sh
#------------------------------------------------------------------------------

function populate_db(){
    local SRC_DIR="${MODULE_DIR}/test/dao/scripts"
    local DEST_DIR="${MODULE_TEST_DIR}/bin"
    cp ${SRC_DIR}/ora_*.sql ${DEST_DIR}
   
    clear_db || return ${?}
    (cd ${DEST_DIR} && RunSqlCmd \
        "ora_t_channel_insert.sql" \
        "ora_t_channel_vo_share_insert.sql" \
        "ora_t_job_insert.sql" \
        "ora_t_file_insert.sql" \
        "ora_t_transfer_insert.sql" \
        "ora_t_stage_req_insert.sql" \
        "ora_t_credential_insert.sql" \
        "ora_t_site_group_insert.sql") || return ${?}
}

# test-dao-ora-install
# Install DAO Oracle UnitTest Data
test_dao_ora_install__DEPENDS="init_libs_and_paths"
function test_dao_ora_install(){
    # Create Template for the UnitTest 
    create_config_xml "glite-transfer-agent-test-dao-ora" ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-dao-ora.config.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-dao-oracle.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-dao-oracle.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-dao-oracle-dumper.config-template.xml
    # Create UnitTest configuration                                   
    config_generator -f ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-dao-ora.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-dao-ora.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-dao-ora.log-properties \
        -O agents-dao-oracle.User=${ORA_USER} \
        -O agents-dao-oracle.Password=${ORA_PWD} \
        -O agents-dao-oracle.ConnectString=${ORA_CONNECTSTRING} \
        -O transfer-agent-dao-oracle-dumper.Path=${MODULE_TEST_DIR}/var \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/transfer-agent-test-dao-ora.log \
        -O log.Priority=DEBUG
    # Create UnitTest configuration with Statement cache size turned on 
    config_generator -f ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-dao-ora.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-dao-ora-wscs.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-dao-ora-wscs.log-properties \
        -O agents-dao-oracle.User=${ORA_USER} \
        -O agents-dao-oracle.Password=${ORA_PWD} \
        -O agents-dao-oracle.ConnectString=${ORA_CONNECTSTRING} \
        -O agents-dao-oracle.StatementCacheSize=50 \
        -O transfer-agent-dao-oracle-dumper.Path=${MODULE_TEST_DIR}/var \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/transfer-agent-test-dao-ora-wscs.log \
        -O log.Priority=DEBUG
    # Populate the DB 
    run_test_function populate_db
}

# test-dao-ora
# DAO Oracle Unit Test
test_dao_ora__DEPENDS="test_dao_ora_install"
function test_dao_ora(){
    (cd ${MODULE_TEST_DIR}/bin && ${MODULE_TEST_DIR}/bin/glite_data_transfer_agent_test_dao \
        -l ${MODULE_TEST_DIR} -s -c glite-transfer-agent-test-dao-ora) || return ${?}
}
# test-dao-ora-wscs
# DAO Oracle Unit Test
function test_dao_ora_wscs(){
    # Init
    run_test_function test_dao_ora_install
    (cd ${MODULE_TEST_DIR}/bin && ${MODULE_TEST_DIR}/bin/glite_data_transfer_agent_test_dao \
        -l ${MODULE_TEST_DIR} -s -c glite-transfer-agent-test-dao-ora-wscs) || return ${?}
}
# test-dao
# DAO Unit Test
test_dao__DEPENDS="test_dao_ora test_dao_ora_wscs"
function test_dao(){
    true
}
 
