#
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
#  Test script for checking the Python NameGeneration plugin
#
#  Authors: Paolo Badino <paolo.badino@cern.ch>
#           Paolo Tedesco <paolo.tedesco@cern.ch>
#  Version info: $Id: TestNameGen.py,v 1.3 2008/11/13 10:43:56 ptedesco Exp $
#  Release: $Name:  $
#

import glite.data.agents.utils

#
# Declare Constants used in the script
#
MODULE_NAME      = "test_namegen"

# Log Functions
DebugPriority = glite.data.agents.utils.LogPriority.Debug
def log_debug(msg):
    global DebugPriority 
    glite.data.agents.utils.Log(MODULE_NAME,DebugPriority,msg)
    
def log_info(msg):
    glite.data.agents.utils.LogInfo(MODULE_NAME,msg)

def log_warn(msg):
    glite.data.agents.utils.LogWarn(MODULE_NAME,msg)

def log_error(msg):
    glite.data.agents.utils.LogError(MODULE_NAME,msg)

#
# Declare the NameGeneration Version supported by this script
#
def NameGenPluginVersion():
    return "1.0"

#
# Init Plugin
#
def InitNameGenPlugin(params):
    log_info("NameGen Plugin initialized")
    return True;

################################################################################

#
# Check if it's an LFN
#
def IsLfn(logical):
    result = False;
    if(logical.startswith('/')):
        result = True;
    elif(logical.lower().startswith('lfn:')):
        result = True;
        
    return result;

#
# TrimLfnProtocol
#
def TrimLfnProtocol(logical):
    l = logical.lower()
    if(l.startswith('lfn://')):
        return logical[6:]
    elif(l.startswith("lfn:")):
        return logical[4:]
        
    return logical;

#
# TrimGuidProtocol
#
def TrimGuidProtocol(logical):
    l = logical.lower()
    if(l.startswith('guid://')):
        return logical[7:]
    elif(l.startswith("guid:")):
        return logical[5:]
        
    return logical;

################################################################################

#
# Generate New SURL. Reimplement the Default Logic for the unit tests purposes
#
def Generate(logical,endpoint,se_path,storage_class):
    log_debug("entering Generate(%s:%s:%s:%s)" % (logical,endpoint,se_path,storage_class))

    # Get the protocol
    protocol_pos = endpoint.index(":");
    
    # Compute Surl Prefix
    surl_prefix = "srm" + endpoint[protocol_pos:] + "?SFN=" + se_path;

    surl = ""
    name_str = "";
    if(IsLfn(logical)):
        name_str = TrimLfnProtocol(logical);
    else:
        # Handle GUID as in the Default Implementation
        str_guid = TrimGuidProtocol(logical);
        guid = glite.data.agents.utils.Guid(str_guid)
        if guid.isNull():
            name_str = "/GUID/" + str_guid;
        else:
            name_str = "/" + str(guid.crossSumHash()) + "/" + str(guid.hash()) \
                     + "/" + str_guid;

    if(se_path.endswith('/')):
        if(name_str.startswith('/')):
            surl = surl_prefix + name_str[1:];
        else:
            surl = surl_prefix + name_str;
    else:
        if(name_str.startswith('/')):
            surl = surl_prefix + name_str;
        else:
            surl = surl_prefix + "/" + name_str;
    
    log_debug("Got SURL %s" % (surl) )
    
    return surl;

if __name__ == "__main__":
    
    InitNameGenPlugin("")

    # Generate With LFN
    surl = Generate("/tmp/test/lfn1.txt","httpg://castor.cern.ch:8443/srm/managerv1","/SE","");
    log_info("Got SURL %s" % (surl) )
    surl = Generate("lfn:/tmp/test/lfn1.txt","httpg://castor.cern.ch:8443/srm/managerv1","/SE","");
    log_info("Got SURL %s" % (surl) )
    surl = Generate("lfn:///tmp/test/lfn1.txt","httpg://castor.cern.ch:8443/srm/managerv1","/SE","");
    log_info("Got SURL %s" % (surl) )
    
    # Generate With GUID
    surl = Generate("0000e6f0-4e81-1255-af7f-000000000000","httpg://castor.cern.ch:8443/srm/managerv1","/SE","");
    log_info("Got SURL %s" % (surl) )
    surl = Generate("guid:0000e6f0-4e81-1255-af7f-000000000000","httpg://castor.cern.ch:8443/srm/managerv1","/SE","");
    log_info("Got SURL %s" % (surl) )
    surl = Generate("guid://0000e6f0-4e81-1255-af7f-000000000000","httpg://castor.cern.ch:8443/srm/managerv1","/SE","");
    log_info("Got SURL %s" % (surl) )
    
    print "Done"
