#!/bin/bash
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Install NameGen Default Data
test_namegen_default_install__DEPENDS="init_unit_test"
function test_namegen_default_install(){
    # Create Template for the UnitTest 
    create_config_xml "glite-transfer-agent-test-namegen-default" ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-namegen-default.config.xml \
        ${GLITE_LOCATION}/share/config/glite-data-agents-common/config-templates/agents-sd.config-template.xml
    # Create UnitTest configuration                                   
    config_generator -f ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-namegen-default.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-namegen-default.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-namegen-default.log-properties \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/transfer-agent-test-namegen-default.log \
        -O log.Priority=DEBUG
}

# NameGen Unit Test 
test_namegen_default__DEPENDS="test_namegen_default_install"
function test_namegen_default(){
    (cd ${MODULE_TEST_DIR}/bin && ${MODULE_TEST_DIR}/bin/glite_data_transfer_agent_test_namegen -l ${MODULE_TEST_DIR} -c glite-transfer-agent-test-namegen-default -s) || return ${?}
}

# Install NameGen Python Data
TEST_NAMEGEN_PYTHON_PACKAGES_DIR=""
test_namegen_python_install__DEPENDS="init_unit_test"
function test_namegen_python_install(){
    # Create Template for the UnitTest 
    create_config_xml "glite-transfer-agent-test-namegen-python" ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-namegen-python.config.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-python.config-template.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-sd.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-namegen-python.config-template.xml
    # Python Path 
    TEST_NAMEGEN_PYTHON_PACKAGES_DIR=`python -c "from distutils import sysconfig; print sysconfig.get_python_lib(1,0,prefix='${GLITE_LOCATION}')"`
    # Copy Python test 
    cp ${MODULE_DIR}/test/namegen/python/scripts/TestNameGen.py ${MODULE_TEST_DIR}/bin
    # Create UnitTest configuration                                   
    config_generator -f ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-namegen-python.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-namegen-python.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-namegen-python.log-properties \
        -O agents-python.PythonPath=${TEST_NAMEGEN_PYTHON_PACKAGES_DIR}:${MODULE_TEST_DIR}/bin \
        -O transfer-agent-namegen-python.NameGenModule=TestNameGen \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/transfer-agent-test-namegen-python.log \
        -O log.Priority=DEBUG
    # Create UnitTest configuration                                   
    config_generator -f ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-namegen-python.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-namegen-python-default.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-namegen-python-default.log-properties \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/transfer-agent-test-namegen-python-default.log \
        -O log.Priority=DEBUG
}

# NameGen Unit Test 
test_namegen_python__DEPENDS="test_namegen_python_install"
function test_namegen_python(){
    (cd ${MODULE_TEST_DIR}/bin && ${MODULE_TEST_DIR}/bin/glite_data_transfer_agent_test_namegen \
        -l ${MODULE_TEST_DIR} -c glite-transfer-agent-test-namegen-python -s) || return ${?}
}

# NameGen Unit Test 
test_namegen_python_default__DEPENDS="test_namegen_python_install"
function test_namegen_python_default(){
    (cd ${MODULE_TEST_DIR}/bin && ${MODULE_TEST_DIR}/bin/glite_data_transfer_agent_test_namegen \
        -l ${MODULE_TEST_DIR} -c glite-transfer-agent-test-namegen-python-default -s) || return ${?}
}

test_namegen__DEPENDS="test_namegen_default test_namegen_python test_namegen_python_default"
function test_namegen(){
    true
}

