#!/usr/bin/python
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import glite.fts
import time

# TestSchemaVersion
#-------------------------------------------------------------------------------
def TestSchemaVersion(version):
    MAJOR_VERSION = 3
    MINOR_VERSION = 3

    v = glite.fts.SchemaVersion()
    if(v != version): 
        return False
    vv = v.split('.')
    if(int(vv[0]) != MAJOR_VERSION):
        return False
    if(int(vv[1]) < MINOR_VERSION):
        return False
    
    return True
    
# TestJob
#-------------------------------------------------------------------------------
def TestJob(job):

    # Test Job Properties
    if(job.id != "10000000-0000-0000-0000-000000000001"):
        return "id"
    if(job.state != glite.fts.JobState.Submitted):
        return "state"
    if(job.voName != "VO1"):
        return "voName"
    if(job.channelName != "CHANNEL_1"):
        return "channelName"
    if(job.priority != 4):
        return "priority"
    if(job.cancelJob != False):
        return "cancelJob"
    if(job.source != "SRC_SITE"):
        return "source"
    if(job.dest != "DST_SITE"):
        return "dest"
    if(job.userDn != "My DN"):
        return "userDn"
    if(job.params != "some params"):
        return "params"
    if(job.reason != "a reason"):
        return "reason"
    if(job.submitTime <= 0):
        return "submitTime"
    if(job.agentDn != "Agent DN"):
        return "agentDn"
    if(job.submitHost != "localhost"):
        return "submitHost"
    if(job.maxTimeInQueue != 0):
        return "maxTimeInQueue"
    if(job.finishTime != -1):
        return "finishTime"
    if(job.myproxyServer != "myproxy.cern.ch"):
        return "myproxyServer"
    if(job.spaceToken != "SPACE_TOKEN"):
        return "spaceToken"
    if(job.storageClass != "volatile"):
        return "storageClass"
                
    # Test Modifiable properties
    job.state = glite.fts.JobState.Failed
    job.reason = "another reason"
    current = int(time.time())
    job.finishTime = current
    if(job.state != glite.fts.JobState.Failed):
        return "state:modified"
    if(job.reason != "another reason"):
        return "reason:modified"
    if(job.finishTime != current):
        return "finishTime:modified"
    
    return ""
    
# TestFile
#-------------------------------------------------------------------------------
def TestFile(file):
    # Test File Properties
    if(file.id != "100"):
        return "id"
    if(file.jobId != "10000000-0000-0000-0000-000000000001"):
        return "jobId"
    if(file.state != glite.fts.FileState.Pending):
        return "state"
    if(file.logical != "lfn:///tmp/test.txt"):
        return "logical"
    if(file.sourceSurl != "srm://srm.test.com/tmp/test.txt"):
        return "sourceSurl"
    if(file.destSurl != "srm://srm.nowhere.com/tmp/test.txt"):
        return "destSurl"
    if(file.reasonClass != glite.fts.ErrorCategory.InternalError):
        return "reasonClass"
    if(file.reason != "a reason"):
        return "reason"
    if(file.failures != 5):
        return "failures"
    if(file.currentFailures != 4):
        return "currentFailures"
    if(file.catalogFailures != 3):
        return "catalogFailures"
    if(file.prestageFailures != 2):
        return "prestageFailures"
    if(file.fileSize != 12345678):
        return "fileSize"
    if(file.checksum != "0x12345"):
        return "checksum"
    if(file.finishTime != -1):
        return "finishTime"
    if(file.agentDn != "Agent DN"):
        return "agentDn"
    
    # Test Modifiable properties
    file.state = glite.fts.FileState.Failed
    file.sourceSurl  = "srm://srm.test.com/tmp/test.txt.1"
    file.destSurl    = "srm://srm.nowhere.com/tmp/test.txt.1"
    file.reasonClass = glite.fts.ErrorCategory.Remote
    file.reason      = "another reason"
    file.failures          = 6
    file.currentFailures   = 5
    file.catalogFailures   = 4
    file.prestagetFailures = 3
    file.fileSize          = 123456789
    file.checksum          = "0x123456"
    current = int(time.time())
    file.finishTime = current
    
    if(file.state != glite.fts.FileState.Failed):
        return "state:modified"
    if(file.sourceSurl != "srm://srm.test.com/tmp/test.txt.1"):
        return "sourceSurl:modified"
    if(file.destSurl != "srm://srm.nowhere.com/tmp/test.txt.1"):
        return "destSurl:modified"
    if(file.reasonClass != glite.fts.ErrorCategory.Remote):
        return "reasonClass:modified"
    if(file.reason != "another reason"):
        return "reason:modified"
    if(file.failures != 6):
        return "failures:modified"
    if(file.currentFailures != 5):
        return "currentFailures:modified"
    if(file.catalogFailures != 4):
        return "catalogFailures:modified"
    if(file.prestagetFailures != 3):
        return "prestagetFailures:modified"
    if(file.fileSize != 123456789):
        return "fileSize:modified"
    if(file.checksum != "0x123456"):
        return "checksum:modified"        
    if(file.finishTime != current):
        return "finishTime:modified"
        
    # added with schema version 3.1.0
    if(file.errorScope != glite.fts.ErrorScope.Source):
        return "errorScope"
    if(file.errorPhase != glite.fts.ErrorPhase.TxPreparation):
        return "errorPhase"
    file.errorScope = glite.fts.ErrorScope.Undef
    file.errorPhase = glite.fts.ErrorPhase.Allocation
    if(file.errorScope != glite.fts.ErrorScope.Undef):
        return "errorScope:modified"
    if(file.errorPhase != glite.fts.ErrorPhase.Allocation):
        return "errorPhase:modified"
        
    return ""
    
# TestTransfer
#-------------------------------------------------------------------------------
def TestTransfer(tx):

    # Test Transfer Properties
    if(tx.requestId != "req_1_1"):
        return "requestId"
    if(tx.fileId != "100"):
        return "fileId"
    if(tx.transferId != 0):
        return "transferId"
    if(tx.jobId != "10000000-0000-0000-0000-000000000001"):
        return "jobId"
    if(tx.state != glite.fts.TransferState.Received):
        return "state"
    if(tx.transferType != "foo"):
        return "type"
    if(tx.sourceTurl != "gsiftp://srm.test.com/tmp/test.txt"):
        return "sourceTurl"
    if(tx.destTurl != "gsiftp://srm.nowhere.com/tmp/test.txt"):
        return "destTurl"
    if(tx.transferTime <= 0):
        return "transferTime"
    if(tx.prepareTime  <= 0):
        return "prepareTime"
    if(tx.duration != 0.1):
        return "duration"
    if(tx.srcPrepDuration != 0.2):
        return "srcPrepDuration"
    if(tx.dstPrepDuration != 0.3):
        return "dstPrepDuration"
    if(tx.txDuration != 0.4):
        return "txDuration"
    if(tx.srcFinalDuration != 0.5):
        return "srcFinalDuration"
    if(tx.dstFinalDuration != 0.6):
        return "dstFinalDuration"
    if(tx.bytesWritten != 12345):
        return "bytesWritten"
    if(tx.throughput != 1.1):
        return "throughput"
    if(tx.reasonClass != glite.fts.ErrorCategory.Security):
        return "reasonClass"
    if(tx.reason != "a reason"):
        return "reason"
    if(tx.fileSize != 12345678):
        return "fileSize"
    if(tx.srcSrmToken != "source_srm_token"):
        return "srcSrmToken"
    if(tx.destSrmToken != "dest_srm_token"):
        return "destSrmToken"
    if(tx.srcHost != "source_host"):
        return "srcHost"
    if(tx.destHost != "dest_host"):
        return "destHost"
    
    # Test Modifiable properties
    tx.state            = glite.fts.TransferState.Failed
    tx.sourceTurl       = "gsiftp://srm.test.com/tmp/test.txt.1"
    tx.destTurl         = "gsiftp://srm.nowhere.com/tmp/test.txt.1"
    tx.reasonClass      = glite.fts.ErrorCategory.Network
    tx.reason           = "another reason"
    tx.fileSize         = 123456789
    tx.duration         = 1.1
    tx.srcPrepDuration  = 1.2
    tx.dstPrepDuration  = 1.3
    tx.txDuration       = 1.4
    tx.srcFinalDuration = 1.5
    tx.dstFinalDuration = 1.6
    tx.bytesWritten     = 123456
    tx.throughput       = 2.1
    current             = int(time.time())
    tx.transferTime     = current
    tx.prepareTime      = current - 10
    tx.srcSrmToken      = "source_srm_token_modified"
    tx.destSrmToken     = "dest_srm_token_modified"
    tx.srcHost          = "source_host_modified"
    tx.destHost         = "dest_host_modified"

    if(tx.state != glite.fts.TransferState.Failed):
        return "state:modified"
    if(tx.sourceTurl != "gsiftp://srm.test.com/tmp/test.txt.1"):
        return "sourceTurl:modified"
    if(tx.destTurl != "gsiftp://srm.nowhere.com/tmp/test.txt.1"):
        return "destTurl:modified"
    if(tx.transferTime != current):
        return "transferTime:modified"
    if(tx.prepareTime != (current - 10)):
        return "prepareTime:modified"
    if(tx.duration != 1.1):
        return "duration:modified"
    if(tx.srcPrepDuration != 1.2):
        return "srcPrepDuration:modified"
    if(tx.dstPrepDuration != 1.3):
        return "dstPrepDuration:modified"
    if(tx.txDuration != 1.4):
        return "txDuration:modified"
    if(tx.srcFinalDuration != 1.5):
        return "srcFinalDuration:modified"
    if(tx.dstFinalDuration != 1.6):
        return "dstFinalDuration:modified"
    if(tx.bytesWritten != 123456):
        return "bytesWritten:modified"
    if(tx.throughput != 2.1):
        return "throughput:modified"
    if(tx.reasonClass != glite.fts.ErrorCategory.Network):
        return "reasonClass:modified"
    if(tx.reason != "another reason"):
        return "reason:modified"
    if(tx.fileSize != 123456789):
        return "fileSize:modified"
    if(tx.srcSrmToken != "source_srm_token_modified"):
        return "srcSrmToken:modified"
    if(tx.destSrmToken != "dest_srm_token_modified"):
        return "destSrmToken:modified"
    if(tx.srcHost != "source_host_modified"):
        return "srcHost:modified"
    if(tx.destHost != "dest_host_modified"):
        return "destHost:modified"

    # added with schema version 3.1.0
    if(tx.errorScope != glite.fts.ErrorScope.Destination):
        return "errorScope"
    if(tx.errorPhase != glite.fts.ErrorPhase.Transfer):
        return "errorPhase"
    if(tx.finishTime <= 0):
        return "finishTime"
    tx.errorScope = glite.fts.ErrorScope.Transfer
    tx.errorPhase = glite.fts.ErrorPhase.Prestaging
    tx.finishTime = current + 20
    if(tx.errorScope != glite.fts.ErrorScope.Transfer):
        return "errorScope:modified"
    if(tx.errorPhase != glite.fts.ErrorPhase.Prestaging):
        return "errorPhase:modified"
    if(tx.finishTime != current + 20):
        return "finishTime:modified"

    return ""
    
# TestStageReq
#-------------------------------------------------------------------------------
def TestStageReq(sr):

    # Test StageReq Properties
    if(sr.requestId != "stagereq_1_1"):
        return "requestId"
    if(sr.fileId != "100"):
        return "fileId"
    if(sr.stageId != 0):
        return "stageId"
    if(sr.jobId != "10000000-0000-0000-0000-000000000001"):
        return "jobId"
    if(sr.state != glite.fts.StageReqState.Submitted):
        return "state"
    if(sr.turl != "gsiftp://srm.test.com/tmp/test.txt"):
        return "turl"
    if(sr.requestTime <= 0):
        return "requestTime"
    if(sr.duration != 0.1):
        return "duration"
    if(sr.finalDuration != 0.2):
        return "finalDuration"
    if(sr.reasonClass != glite.fts.ErrorCategory.SourcePreparation):
        return "reasonClass"
    if(sr.reason != "a reason"):
        return "reason"
    if(sr.fileSize != 12345678):
        return "fileSize"
    
    # Test Modifiable properties
    sr.state = glite.fts.StageReqState.Finalizing
    sr.turl  = "gsiftp://srm.test.com/tmp/test.txt.1"
    sr.reasonClass   = glite.fts.ErrorCategory.Catalog
    sr.reason        = "another reason"
    sr.fileSize      = 123456789
    sr.duration      = 1.1
    sr.finalDuration = 1.5
    current = int(time.time())
    sr.requestTime = current
    if(sr.state != glite.fts.StageReqState.Finalizing):
        return "state:modified"
    if(sr.turl != "gsiftp://srm.test.com/tmp/test.txt.1"):
        return "turl:modified"
    if(sr.requestTime != current):
        return "requestTime:modified"
    if(sr.duration != 1.1):
        return "duration:modified"
    if(sr.finalDuration != 1.5):
        return "finalDuration:modified"
    if(sr.reasonClass != glite.fts.ErrorCategory.Catalog):
        return "reasonClass:modified"
    if(sr.reason != "another reason"):
        return "reason:modified"
    if(sr.fileSize != 123456789):
        return "fileSize:modified"

    # added with schema version 3.1.0
    if(sr.errorScope != glite.fts.ErrorScope.Agent):
        return "errorScope"
    if(sr.errorPhase != glite.fts.ErrorPhase.CatalogRegistration):
        return "errorPhase"
    if(sr.finishTime <= 0):
        return "finishTime"
    sr.errorScope = glite.fts.ErrorScope.Undef
    sr.errorPhase = glite.fts.ErrorPhase.Waiting
    sr.finishTime = current + 20
    if(sr.errorScope != glite.fts.ErrorScope.Undef):
        return "errorScope:modified"
    if(sr.errorPhase != glite.fts.ErrorPhase.Waiting):
        return "errorPhase:modified"
    if(sr.finishTime != current + 20):
        return "finishTime:modified"

    return ""
        
# TestFileArray
#-------------------------------------------------------------------------------
def TestFileArray(files):
    if(len(files) != 10):
        return "file array size"

    count = 0
    for file in files:
        result = TestFile(file)
        if result != "":
            return "%d: %s" % (count,result)
        count = count + 1
    return ""
            
# TestTransferArray
#-------------------------------------------------------------------------------
def TestTransferArray(transfers):
    if(len(transfers) != 15):
        return "transfer array size"

    count = 0
    for tx in transfers:
        result = TestTransfer(tx)
        if result != "":
            return "%d: %s" % (count,result)
        count = count + 1
    return ""


if __name__ == "__main__":
    TestSchemaVersion("3.3.0")
