#!/bin/bash
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Install Actions UnitTest Data
test_regressions_13724_ora_install__DEPENDS="init_unit_test"
function test_regressions_13724_ora_install(){

    # Populate DB 
    clear_db || return ${?} 
    local DEST_DIR=${MODULE_TEST_DIR}/bin
    local SRC_DIR=${MODULE_DIR}/test/regressions/13724/scripts
    cp ${SRC_DIR}/test-t*.sql ${DEST_DIR}
    (cd ${DEST_DIR} && RunSqlCmd \
        "test-t_channel_insert.sql" \
        "test-t_channel_vo_share_insert.sql" \
        "test-t_job_insert.sql" \
        "test-t_file_insert.sql" \
        "test-t_transfer_insert.sql") || return ${?} 

    # Create Template for the UnitTest 
    create_config_xml "glite-transfer-agent-test-regressions-13724-ora" ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-regressions-13724-oracle.config.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-cred-myproxy.config-template.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-sd.config-template.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-python.config-template.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-dao-oracle.config-template.xml \
        ${MODULE_DIR}/test/ts/etc/transfer-agent-ts-stub.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-dao-oracle.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-channel-actions.config-template.xml
    # Create UnitTest configuration                                   
    config_generator -f ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-regressions-13724-oracle.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-regressions-13724-ora.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-regressions-13724-ora.log-properties \
        -O agent-cred-myproxy.Server=${MYPROXY_SERVER} \
        -O agent-cred-myproxy.ProxyLifetime=300 \
        -O agent-cred-myproxy.MinValidityTime=0 \
        -O agents-dao-oracle.User=${ORA_USER} \
        -O agents-dao-oracle.Password=${ORA_PWD} \
        -O agents-dao-oracle.ConnectString=${ORA_CONNECTSTRING} \
        -O agents-dao-oracle.Path=${MODULE_TEST_DIR}/var \
        -O transfer-agent-ts-stub.MaxTransfers=50 \
        -O transfer-agent-ts-stub.MaxRequestSize=1 \
        -O transfer-agent-channel-actions.EnableDelegation=false \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/glite-transfer-agent-test-regressions-13724-oracle.log \
        -O log.Priority=DEBUG
}

# Actions Unit Test 
test_regressions_13724_ora__DEPENDS="test_regressions_13724_ora_install"
function test_regressions_13724_ora(){
    (cd ${MODULE_TEST_DIR}/bin && ${MODULE_TEST_DIR}/bin/glite_data_transfer_agent_test_regressions_13724 \
        -l ${MODULE_TEST_DIR} -c glite-transfer-agent-test-regressions-13724-ora -s) || return ${?}
    rm -rf ${MODULE_TEST_DIR}/bin/ts-stub__*
}

# Install Scheduler UnitTest Data
test_regressions_13724__DEPENDS="test_regressions_13724_ora"
function test_regressions_13724(){
    true
}
