#!/bin/bash
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Install SD stub Target 
function test_regressions_30271_sd_stub_install(){
    # Create services.xml 
    cat > ${MODULE_TEST_DIR}/etc/services.xml << EOD
<services>
  <service name="CERN-SRM">
    <parameters>
      <endpoint>httpg://host.cern.ch:8443/srm/managerv2</endpoint>
      <type>SRM</type>
      <version>2.2.0</version>
      <site>test30271.cern.ch</site>
      <param name="ALLOCATE_VO_1:SEMountPoint">/castor/cern.ch/SE/</param>
    </parameters>
  </service>
  <service name="INFN-SRM">
    <parameters>
      <endpoint>httpg://host.infn.it:8443/srm/managerv2</endpoint>
      <type>SRM</type>
      <version>2.2.0</version>
      <site>test30271.infn.it</site>
      <param name="ALLOCATE_VO_1:SEMountPoint">/castor/infn.it/EGEE-SE/</param>
    </parameters>
  </service>
</services>
EOD
}

# Install regression UnitTest Data
test_regressions_30271_ora_install__DEPENDS="init_unit_test test_regressions_30271_sd_stub_install"
function test_regressions_30271_ora_install(){

    # Populate DB 
    clear_db || return ${?} 
    local DEST_DIR=${MODULE_TEST_DIR}/bin
    local SRC_DIR=${MODULE_DIR}/test/regressions/30271/scripts
    cp ${SRC_DIR}/test-t*.sql ${DEST_DIR}
    (cd ${DEST_DIR} && RunSqlCmd \
        "test-t_channel_insert.sql" \
        "test-t_channel_vo_share_insert.sql" \
        "test-t_job_insert.sql" \
        "test-t_file_insert.sql" \
        "test-t_transfer_insert.sql") || return ${?} 

    # Create Template for the UnitTest 
    local SRC_DIR=${AGENTS_COMMON_CONFIG_TEMPLATES}
    create_config_xml "glite-transfer-agent-test-regressions-30271-ora" ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-regressions-30271-oracle.config.xml \
        ${SRC_DIR}/agents-cred-myproxy.config-template.xml \
        ${SRC_DIR}/agents-sd.config-template.xml \
        ${SRC_DIR}/agents-dao-oracle.config-template.xml \
        ${MODULE_DIR}/test/ts/etc/transfer-agent-ts-stub.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-dao-oracle.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-vo-actions.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-channel-actions.config-template.xml

    # =============================================================== 
    # Create UnitTest configuration                                   
    # =============================================================== 
    config_generator -f ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-regressions-30271-oracle.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-regressions-30271-ora.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-regressions-30271-ora.log-properties \
        -O agents-cred-myproxy.Server=${MYPROXY_SERVER} \
        -O agents-cred-myproxy.ProxyLifetime=300 \
        -O agents-cred-myproxy.MinValidityTime=0 \
        -O agents-dao-oracle.User=${ORA_USER} \
        -O agents-dao-oracle.Password=${ORA_PWD} \
        -O agents-dao-oracle.ConnectString=${ORA_CONNECTSTRING} \
        -O transfer-agent-vo-actions.EnableDelegation=false \
        -O transfer-agent-vo-actions.MaxFailures=6 \
        -O transfer-agent-vo-actions.ResubmitDelay=300 \
        -O transfer-agent-vo-actions.EnableUnknownSource=false \
        -O transfer-agent-vo-actions.EnableUnknownDest=true \
        -O transfer-agent-channel-actions.EnableDelegation=false \
        -O transfer-agent-ts-stub.MaxTransfers=20 \
        -O transfer-agent-ts-stub.MaxRequestSize=3 \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/glite-transfer-agent-test-regressions-30271-oracle.log \
        -O log.Priority=DEBUG
} 

# Actions Unit Test 
test_regressions_30271_ora__DEPENDS="test_regressions_30271_ora_install"
function test_regressions_30271_ora(){
    (cd ${MODULE_TEST_DIR}/bin && ${MODULE_TEST_DIR}/bin/glite_data_transfer_agent_test_regressions_30271 \
        -l ${MODULE_TEST_DIR} -c glite-transfer-agent-test-regressions-30271-ora -s) || return ${?}
}

# Install Scheduler UnitTest Data
test_regressions_30271__DEPENDS="test_regressions_30271_ora"
function test_regressions_30271(){
    true
}
